@@ -1,10 +1,19 @@
 //-----------------------------------------------------------------------------
-// Jonathan Westhues, Mar 2006
-// Edits by Gerhard de Koning Gans, Sep 2007 (##)
+// Copyright (C) Jonathan Westhues, Mar 2006
+// Copyright (C) Gerhard de Koning Gans, Sep 2007
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
 //
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // The main application code. This is the first thing called after start.c
 // executes.
@@ -23,6 +32,7 @@
 #include "printf.h"
 #include "legicrf.h"
 #include "BigBuf.h"
+#include "iclass_cmd.h"
 #include "iso14443a.h"
 #include "iso14443b.h"
 #include "iso15693.h"
@@ -39,6 +49,7 @@
 #include "hfsnoop.h"
 #include "lfops.h"
 #include "lfsampling.h"
+#include "lfzx.h"
 #include "mifarecmd.h"
 #include "mifaredesfire.h"
 #include "mifaresim.h"
@@ -163,7 +174,9 @@ static void MeasureAntennaTuning(void) {
         uint8_t results[256];
     } PACKED payload;
 
-    memset(payload.results, 0, sizeof(payload.results));
+    // Need to clear all values to ensure non-random responses.
+    memset(&payload, 0, sizeof(payload));
+    // memset(payload.results, 0, sizeof(payload.results));
 
     sample_config *sc = getSamplingConfig();
     payload.divisor = sc->divisor;
@@ -539,6 +552,13 @@ static void SendCapabilities(void) {
 #else
     capabilities.compiled_with_lcd = false;
 #endif
+
+#ifdef WITH_ZX8211
+    capabilities.compiled_with_zx8211 = true;
+#else
+    capabilities.compiled_with_zx8211 = false;
+#endif
+
     reply_ng(CMD_CAPABILITIES, PM3_SUCCESS, (uint8_t *)&capabilities, sizeof(capabilities));
 }
 
@@ -810,7 +830,7 @@ static void PacketReceived(PacketCommandNG *packet) {
                 bool     verbose : 1;
             } PACKED;
             struct p *payload = (struct p *)packet->data.asBytes;
-            uint32_t bits = SampleLF(payload->verbose, payload->samples);
+            uint32_t bits = SampleLF(payload->verbose, payload->samples, true);
             reply_ng(CMD_LF_ACQ_RAW_ADC, PM3_SUCCESS, (uint8_t *)&bits, sizeof(bits));
             break;
         }
@@ -821,7 +841,8 @@ static void PacketReceived(PacketCommandNG *packet) {
                 uint16_t period_1;
                 uint8_t  symbol_extra[LF_CMDREAD_MAX_EXTRA_SYMBOLS];
                 uint16_t period_extra[LF_CMDREAD_MAX_EXTRA_SYMBOLS];
-                uint32_t samples : 31;
+                uint32_t samples : 30;
+                bool     keep : 1;
                 bool     verbose : 1;
             } PACKED;
             struct p *payload = (struct p *)packet->data.asBytes;
@@ -829,7 +850,7 @@ static void PacketReceived(PacketCommandNG *packet) {
             uint16_t period_extra[LF_CMDREAD_MAX_EXTRA_SYMBOLS];
             memcpy(symbol_extra, payload->symbol_extra, sizeof(symbol_extra));
             memcpy(period_extra, payload->period_extra, sizeof(period_extra));
-            ModThenAcquireRawAdcSamples125k(payload->delay, payload->period_0, payload->period_1, symbol_extra, period_extra, packet->data.asBytes + sizeof(struct p), payload->verbose, payload->samples);
+            ModThenAcquireRawAdcSamples125k(payload->delay, payload->period_0, payload->period_1, symbol_extra, period_extra, packet->data.asBytes + sizeof(struct p), payload->verbose, payload->keep, payload->samples, true);
             break;
         }
         case CMD_LF_SNIFF_RAW_ADC: {
@@ -838,13 +859,13 @@ static void PacketReceived(PacketCommandNG *packet) {
                 bool     verbose : 1;
             } PACKED;
             struct p *payload = (struct p *)packet->data.asBytes;
-            uint32_t bits = SniffLF(payload->verbose, payload->samples);
+            uint32_t bits = SniffLF(payload->verbose, payload->samples, true);
             reply_ng(CMD_LF_SNIFF_RAW_ADC, PM3_SUCCESS, (uint8_t *)&bits, sizeof(bits));
             break;
         }
         case CMD_LF_HID_WATCH: {
             uint32_t high, low;
-            int res = lf_hid_watch(0, &high, &low);
+            int res = lf_hid_watch(0, &high, &low, true);
             reply_ng(CMD_LF_HID_WATCH, res, NULL, 0);
             break;
         }
@@ -875,19 +896,19 @@ static void PacketReceived(PacketCommandNG *packet) {
         }
         case CMD_LF_HID_CLONE: {
             lf_hidsim_t *payload = (lf_hidsim_t *)packet->data.asBytes;
-            CopyHIDtoT55x7(payload->hi2, payload->hi, payload->lo, payload->longFMT, payload->Q5, payload->EM);
+            CopyHIDtoT55x7(payload->hi2, payload->hi, payload->lo, payload->longFMT, payload->Q5, payload->EM, true);
             break;
         }
         case CMD_LF_IO_WATCH: {
             uint32_t high, low;
-            int res = lf_io_watch(0, &high, &low);
+            int res = lf_io_watch(0, &high, &low, true);
             reply_ng(CMD_LF_IO_WATCH, res, NULL, 0);
             break;
         }
         case CMD_LF_EM410X_WATCH: {
             uint32_t high;
             uint64_t low;
-            int res = lf_em410x_watch(0, &high, &low);
+            int res = lf_em410x_watch(0, &high, &low, true);
             reply_ng(CMD_LF_EM410X_WATCH, res, NULL, 0);
             break;
         }
@@ -899,12 +920,12 @@ static void PacketReceived(PacketCommandNG *packet) {
                 uint32_t low;
             } PACKED;
             struct p *payload = (struct p *)packet->data.asBytes;
-            int res = copy_em410x_to_t55xx(payload->card, payload->clock, payload->high, payload->low);
+            int res = copy_em410x_to_t55xx(payload->card, payload->clock, payload->high, payload->low, true);
             reply_ng(CMD_LF_EM410X_WRITE, res, NULL, 0);
             break;
         }
         case CMD_LF_TI_READ: {
-            ReadTItag();
+            ReadTItag(true);
             break;
         }
         case CMD_LF_TI_WRITE: {
@@ -914,7 +935,7 @@ static void PacketReceived(PacketCommandNG *packet) {
                 uint16_t crc;
             } PACKED;
             struct p *payload = (struct p *)packet->data.asBytes;
-            WriteTItag(payload->high, payload->low, packet->crc);
+            WriteTItag(payload->high, payload->low, packet->crc, true);
             break;
         }
         case CMD_LF_SIMULATE: {
@@ -943,16 +964,16 @@ static void PacketReceived(PacketCommandNG *packet) {
                 uint8_t  downlink_mode;
             } PACKED;
             struct p *payload = (struct p *) packet->data.asBytes;
-            T55xxReadBlock(payload->page, payload->pwdmode, false, payload->blockno, payload->password, payload->downlink_mode);
+            T55xxReadBlock(payload->page, payload->pwdmode, false, payload->blockno, payload->password, payload->downlink_mode, true);
             break;
         }
         case CMD_LF_T55XX_WRITEBL: {
             // uses NG format
-            T55xxWriteBlock(packet->data.asBytes);
+            T55xxWriteBlock(packet->data.asBytes, true);
             break;
         }
         case CMD_LF_T55XX_DANGERRAW: {
-            T55xxDangerousRawTest(packet->data.asBytes);
+            T55xxDangerousRawTest(packet->data.asBytes, true);
             break;
         }
         case CMD_LF_T55XX_WAKEUP: {
@@ -961,19 +982,19 @@ static void PacketReceived(PacketCommandNG *packet) {
                 uint8_t flags;
             } PACKED;
             struct p *payload = (struct p *) packet->data.asBytes;
-            T55xxWakeUp(payload->password, payload->flags);
+            T55xxWakeUp(payload->password, payload->flags, true);
             break;
         }
         case CMD_LF_T55XX_RESET_READ: {
-            T55xxResetRead(packet->data.asBytes[0] & 0xff);
+            T55xxResetRead(packet->data.asBytes[0] & 0xff, true);
             break;
         }
         case CMD_LF_T55XX_CHK_PWDS: {
-            T55xx_ChkPwds(packet->data.asBytes[0] & 0xff);
+            T55xx_ChkPwds(packet->data.asBytes[0] & 0xff, true);
             break;
         }
         case CMD_LF_PCF7931_READ: {
-            ReadPCF7931();
+            ReadPCF7931(true);
             break;
         }
         case CMD_LF_PCF7931_WRITE: {
@@ -983,7 +1004,8 @@ static void PacketReceived(PacketCommandNG *packet) {
                 packet->data.asBytes[7] - 128, packet->data.asBytes[8] - 128,
                 packet->oldarg[0],
                 packet->oldarg[1],
-                packet->oldarg[2]
+                packet->oldarg[2],
+                true
             );
             break;
         }
@@ -992,7 +1014,7 @@ static void PacketReceived(PacketCommandNG *packet) {
                 uint32_t password;
             } PACKED;
             struct p *payload = (struct p *) packet->data.asBytes;
-            EM4xLogin(payload->password);
+            EM4xLogin(payload->password, true);
             break;
         }
         case CMD_LF_EM4X_BF: {
@@ -1001,7 +1023,7 @@ static void PacketReceived(PacketCommandNG *packet) {
                 uint32_t n;
             } PACKED;
             struct p *payload = (struct p *) packet->data.asBytes;
-            EM4xBruteforce(payload->start_pwd, payload->n);
+            EM4xBruteforce(payload->start_pwd, payload->n, true);
             break;
         }
         case CMD_LF_EM4X_READWORD: {
@@ -1011,7 +1033,7 @@ static void PacketReceived(PacketCommandNG *packet) {
                 uint8_t usepwd;
             } PACKED;
             struct p *payload = (struct p *) packet->data.asBytes;
-            EM4xReadWord(payload->address, payload->password, payload->usepwd);
+            EM4xReadWord(payload->address, payload->password, payload->usepwd, true);
             break;
         }
         case CMD_LF_EM4X_WRITEWORD: {
@@ -1022,7 +1044,7 @@ static void PacketReceived(PacketCommandNG *packet) {
                 uint8_t usepwd;
             } PACKED;
             struct p *payload = (struct p *) packet->data.asBytes;
-            EM4xWriteWord(payload->address, payload->data, payload->password, payload->usepwd);
+            EM4xWriteWord(payload->address, payload->data, payload->password, payload->usepwd, true);
             break;
         }
         case CMD_LF_EM4X_PROTECTWORD: {
@@ -1032,12 +1054,12 @@ static void PacketReceived(PacketCommandNG *packet) {
                 uint8_t usepwd;
             } PACKED;
             struct p *payload = (struct p *) packet->data.asBytes;
-            EM4xProtectWord(payload->data, payload->password, payload->usepwd);
+            EM4xProtectWord(payload->data, payload->password, payload->usepwd, true);
             break;
         }
         case CMD_LF_AWID_WATCH:  {
             uint32_t high, low;
-            int res = lf_awid_watch(0, &high, &low);
+            int res = lf_awid_watch(0, &high, &low, true);
             reply_ng(CMD_LF_AWID_WATCH, res, NULL, 0);
             break;
         }
@@ -1048,7 +1070,7 @@ static void PacketReceived(PacketCommandNG *packet) {
                 uint8_t blocks[8];
             } PACKED;
             struct p *payload = (struct p *)packet->data.asBytes;
-            CopyVikingtoT55xx(payload->blocks, payload->Q5, payload->EM);
+            CopyVikingtoT55xx(payload->blocks, payload->Q5, payload->EM, true);
             break;
         }
         case CMD_LF_COTAG_READ: {
@@ -1056,43 +1078,43 @@ static void PacketReceived(PacketCommandNG *packet) {
                 uint8_t mode;
             } PACKED;
             struct p *payload = (struct p *)packet->data.asBytes;
-            Cotag(payload->mode);
+            Cotag(payload->mode, true);
             break;
         }
 #endif
 
 #ifdef WITH_HITAG
         case CMD_LF_HITAG_SNIFF: { // Eavesdrop Hitag tag, args = type
-            SniffHitag2();
+            SniffHitag2(true);
 //            SniffHitag2(packet->oldarg[0]);
             reply_ng(CMD_LF_HITAG_SNIFF, PM3_SUCCESS, NULL, 0);
             break;
         }
         case CMD_LF_HITAG_SIMULATE: { // Simulate Hitag tag, args = memory content
-            SimulateHitag2();
+            SimulateHitag2(true);
             break;
         }
         case CMD_LF_HITAG_READER: { // Reader for Hitag tags, args = type and function
-            ReaderHitag((hitag_function)packet->oldarg[0], (hitag_data *)packet->data.asBytes);
+            ReaderHitag((hitag_function)packet->oldarg[0], (hitag_data *)packet->data.asBytes, true);
             break;
         }
         case CMD_LF_HITAGS_SIMULATE: { // Simulate Hitag s tag, args = memory content
-            SimulateHitagSTag((bool)packet->oldarg[0], packet->data.asBytes);
+            SimulateHitagSTag((bool)packet->oldarg[0], packet->data.asBytes, true);
             break;
         }
         case CMD_LF_HITAGS_TEST_TRACES: { // Tests every challenge within the given file
-            check_challenges((bool)packet->oldarg[0], packet->data.asBytes);
+            Hitag_check_challenges(packet->data.asBytes, packet->oldarg[0], true);
             break;
         }
         case CMD_LF_HITAGS_READ: { //Reader for only Hitag S tags, args = key or challenge
-            ReadHitagS((hitag_function)packet->oldarg[0], (hitag_data *)packet->data.asBytes);
+            ReadHitagS((hitag_function)packet->oldarg[0], (hitag_data *)packet->data.asBytes, true);
             break;
         }
         case CMD_LF_HITAGS_WRITE: { //writer for Hitag tags args=data to write,page and key or challenge
             if ((hitag_function)packet->oldarg[0] < 10) {
-                WritePageHitagS((hitag_function)packet->oldarg[0], (hitag_data *)packet->data.asBytes, packet->oldarg[2]);
+                WritePageHitagS((hitag_function)packet->oldarg[0], (hitag_data *)packet->data.asBytes, packet->oldarg[2], true);
             } else {
-                WriterHitag((hitag_function)packet->oldarg[0], (hitag_data *)packet->data.asBytes, packet->oldarg[2]);
+                WriterHitag((hitag_function)packet->oldarg[0], (hitag_data *)packet->data.asBytes, packet->oldarg[2], true);
             }
             break;
         }
@@ -1106,27 +1128,27 @@ static void PacketReceived(PacketCommandNG *packet) {
 
 #ifdef WITH_EM4x50
         case CMD_LF_EM4X50_INFO: {
-            em4x50_info((em4x50_data_t *)packet->data.asBytes);
+            em4x50_info((em4x50_data_t *)packet->data.asBytes, true);
             break;
         }
         case CMD_LF_EM4X50_WRITE: {
-            em4x50_write((em4x50_data_t *)packet->data.asBytes);
+            em4x50_write((em4x50_data_t *)packet->data.asBytes, true);
             break;
         }
         case CMD_LF_EM4X50_WRITEPWD: {
-            em4x50_writepwd((em4x50_data_t *)packet->data.asBytes);
+            em4x50_writepwd((em4x50_data_t *)packet->data.asBytes, true);
             break;
         }
         case CMD_LF_EM4X50_READ: {
-            em4x50_read((em4x50_data_t *)packet->data.asBytes);
+            em4x50_read((em4x50_data_t *)packet->data.asBytes, true);
             break;
         }
         case CMD_LF_EM4X50_BRUTE: {
-            em4x50_brute((em4x50_data_t *)packet->data.asBytes);
+            em4x50_brute((em4x50_data_t *)packet->data.asBytes, true);
             break;
         }
         case CMD_LF_EM4X50_LOGIN: {
-            em4x50_login((uint32_t *)packet->data.asBytes);
+            em4x50_login((uint32_t *)packet->data.asBytes, true);
             break;
         }
         case CMD_LF_EM4X50_SIM: {
@@ -1136,11 +1158,11 @@ static void PacketReceived(PacketCommandNG *packet) {
             // destroy the Emulator Memory.
             //-----------------------------------------------------------------------------
             FpgaDownloadAndGo(FPGA_BITSTREAM_LF);
-            em4x50_sim((uint32_t *)packet->data.asBytes);
+            em4x50_sim((uint32_t *)packet->data.asBytes, true);
             break;
         }
         case CMD_LF_EM4X50_READER: {
-            em4x50_reader();
+            em4x50_reader(true);
             break;
         }
         case CMD_LF_EM4X50_ESET: {
@@ -1160,34 +1182,45 @@ static void PacketReceived(PacketCommandNG *packet) {
             // destroy the Emulator Memory.
             //-----------------------------------------------------------------------------
             FpgaDownloadAndGo(FPGA_BITSTREAM_LF);
-            em4x50_chk((uint8_t *)packet->data.asBytes);
+            em4x50_chk((uint8_t *)packet->data.asBytes, true);
             break;
         }
 #endif
 
 #ifdef WITH_EM4x70
         case CMD_LF_EM4X70_INFO: {
-            em4x70_info((em4x70_data_t *)packet->data.asBytes);
+            em4x70_info((em4x70_data_t *)packet->data.asBytes, true);
             break;
         }
         case CMD_LF_EM4X70_WRITE: {
-            em4x70_write((em4x70_data_t *)packet->data.asBytes);
+            em4x70_write((em4x70_data_t *)packet->data.asBytes, true);
             break;
         }
         case CMD_LF_EM4X70_UNLOCK: {
-            em4x70_unlock((em4x70_data_t *)packet->data.asBytes);
+            em4x70_unlock((em4x70_data_t *)packet->data.asBytes, true);
             break;
         }
         case CMD_LF_EM4X70_AUTH: {
-            em4x70_auth((em4x70_data_t *)packet->data.asBytes);
+            em4x70_auth((em4x70_data_t *)packet->data.asBytes, true);
             break;
         }
         case CMD_LF_EM4X70_WRITEPIN: {
-            em4x70_write_pin((em4x70_data_t *)packet->data.asBytes);
+            em4x70_write_pin((em4x70_data_t *)packet->data.asBytes, true);
             break;
         }
         case CMD_LF_EM4X70_WRITEKEY: {
-            em4x70_write_key((em4x70_data_t *)packet->data.asBytes);
+            em4x70_write_key((em4x70_data_t *)packet->data.asBytes, true);
+            break;
+        }
+#endif
+
+#ifdef WITH_ZX8211
+        case CMD_LF_ZX_READ: {
+            zx8211_read((zx8211_data_t *)packet->data.asBytes, true);
+            break;
+        }
+        case CMD_LF_ZX_WRITE: {
+            zx8211_write((zx8211_data_t *)packet->data.asBytes, true);
             break;
         }
 #endif
@@ -1551,12 +1584,13 @@ static void PacketReceived(PacketCommandNG *packet) {
             MifareGen3Freez();
             break;
         }
-        case CMD_HF_MIFARE_G3_RDBL: {
+        case CMD_HF_MIFARE_G4_RDBL: {
             struct p {
                 uint8_t blockno;
+                uint8_t pwd[4];
             } PACKED;
             struct p *payload = (struct p *) packet->data.asBytes;
-            MifareG3ReadBlk(payload->blockno);
+            MifareG4ReadBlk(payload->blockno, payload->pwd);
             break;
         }
         case CMD_HF_MIFARE_PERSONALIZE_UID: {
@@ -1661,7 +1695,8 @@ static void PacketReceived(PacketCommandNG *packet) {
             break;
         }
         case CMD_HF_ICLASS_READER: {
-            ReaderIClass(packet->oldarg[0]);
+            iclass_card_select_t *payload = (iclass_card_select_t *) packet->data.asBytes;
+            ReaderIClass(payload->flags);
             break;
         }
         case CMD_HF_ICLASS_EML_MEMSET: {
@@ -2011,7 +2046,7 @@ static void PacketReceived(PacketCommandNG *packet) {
                 reply_ng(CMD_LF_UPLOAD_SIM_SAMPLES, PM3_EOVFLOW, NULL, 0);
                 break;
             }
-            // ensure len bytes copied wont go past end of bigbuf
+            // ensure len bytes copied won't go past end of bigbuf
             uint16_t len = MIN(BigBuf_get_size() - payload->offset, sizeof(payload->data));
 
             uint8_t *mem = BigBuf_get_addr();
@@ -2250,9 +2285,9 @@ static void PacketReceived(PacketCommandNG *packet) {
         case CMD_FLASHMEM_WIPE: {
             LED_B_ON();
             uint8_t page = packet->oldarg[0];
-            uint8_t initalwipe = packet->oldarg[1];
+            uint8_t initialwipe = packet->oldarg[1];
             bool isok = false;
-            if (initalwipe) {
+            if (initialwipe) {
                 isok = Flash_WipeMemory();
                 reply_mix(CMD_ACK, isok, 0, 0, 0, 0);
                 LED_B_OFF();
