@@ -1,20 +1,22 @@
 //-----------------------------------------------------------------------------
-// Gerhard de Koning Gans - May 2008
-// Hagen Fritsch - June 2010
-// Gerhard de Koning Gans - May 2011
-// Gerhard de Koning Gans - June 2012 - Added iClass card and reader emulation
-// piwi - 2019
+// Copyright (C) Gerhard de Koning Gans - May 2008
+// Contribution made during a security research at Radboud University Nijmegen
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
 //
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // Routines to support iClass.
 //-----------------------------------------------------------------------------
-// Contribution made during a security research at Radboud University Nijmegen
-//
-// Please feel free to contribute and extend iClass support!!
-//-----------------------------------------------------------------------------
 #include "iclass.h"
 
 #include "proxmark3_arm.h"
@@ -34,6 +36,7 @@
 #include "protocols.h"
 #include "ticks.h"
 #include "iso15693.h"
+#include "iclass_cmd.h"              /* iclass_card_select_t struct */
 
 static uint8_t get_pagemap(const picopass_hdr_t *hdr) {
     return (hdr->conf.fuses & (FUSE_CRYPT0 | FUSE_CRYPT1)) >> 3;
@@ -91,7 +94,7 @@ void SniffIClass(uint8_t jam_search_len, uint8_t *jam_search_string) {
     SniffIso15693(jam_search_len, jam_search_string);
 }
 
-static void rotateCSN(uint8_t *original_csn, uint8_t *rotated_csn) {
+static void rotateCSN(const uint8_t *original_csn, uint8_t *rotated_csn) {
     for (uint8_t i = 0; i < 8; i++) {
         rotated_csn[i] = (original_csn[i] >> 3) | (original_csn[(i + 1) % 8] << 5);
     }
@@ -1246,7 +1249,7 @@ static void iclass_send_as_reader(uint8_t *frame, int len, uint32_t *start_time,
     CodeIso15693AsReader(frame, len);
     tosend_t *ts = get_tosend();
     TransmitTo15693Tag(ts->buf, ts->max, start_time);
-    *end_time = *start_time + (32 * ((8 * ts->max) - 4)); // substract the 4 padding bits after EOF
+    *end_time = *start_time + (32 * ((8 * ts->max) - 4)); // subtract the 4 padding bits after EOF
     LogTrace_ISO15693(frame, len, (*start_time * 4), (*end_time * 4), NULL, true);
 }
 
@@ -1402,13 +1405,8 @@ bool select_iclass_tag(picopass_hdr_t *hdr, bool use_credit_key, uint32_t *eof_t
 // turn off afterwards
 void ReaderIClass(uint8_t flags) {
 
-    picopass_hdr_t hdr = {0};
-//    uint8_t last_csn[8] = {0, 0, 0, 0, 0, 0, 0, 0};
-    uint8_t resp[ICLASS_BUFFER_SIZE] = {0};
-    memset(resp, 0xFF, sizeof(resp));
-
-//    bool flag_readonce = flags & FLAG_ICLASS_READER_ONLY_ONCE;    // flag to read until one tag is found successfully
-    bool use_credit_key = flags & FLAG_ICLASS_READER_CREDITKEY;     // flag to use credit key
+    // flag to use credit key
+    bool use_credit_key = ((flags & FLAG_ICLASS_READER_CREDITKEY) == FLAG_ICLASS_READER_CREDITKEY);
 
     if ((flags & FLAG_ICLASS_READER_INIT) == FLAG_ICLASS_READER_INIT) {
         Iso15693InitReader();
@@ -1418,13 +1416,14 @@ void ReaderIClass(uint8_t flags) {
         clear_trace();
     }
 
-    uint8_t result_status = 0;
+
+    uint8_t res = 0;
     uint32_t eof_time = 0;
-    bool status = select_iclass_tag_ex(&hdr, use_credit_key, &eof_time, &result_status);
-    if (status == false) {
-        reply_mix(CMD_ACK, 0xFF, 0, 0, NULL, 0);
-        switch_off();
-        return;
+    picopass_hdr_t hdr = {0};
+
+    if (select_iclass_tag_ex(&hdr, use_credit_key, &eof_time, &res) == false) {
+        reply_ng(CMD_HF_ICLASS_READER, PM3_ERFTRANS, NULL, 0);
+        goto out;
     }
 
     // Page mapping for secure mode
@@ -1443,30 +1442,14 @@ void ReaderIClass(uint8_t flags) {
     // Return to client, e 6 * 8 bytes of data.
     // with 0xFF:s in block 3 and 4.
 
-    LED_B_ON();
-    reply_mix(CMD_ACK, result_status, 0, 0, (uint8_t *)&hdr, sizeof(hdr));
+    iclass_card_select_resp_t payload = {
+        .status = res
+    };
+    memcpy(&payload.header.hdr, &hdr, sizeof(picopass_hdr_t));
 
-    //Send back to client, but don't bother if we already sent this -
-    //  only useful if looping in arm (not try_once && not abort_after_read)
-    /*
-    if (memcmp(last_csn, card_data, 8) != 0) {
-
-        reply_mix(CMD_ACK, result_status, 0, 0, card_data, sizeof(card_data));
-        if (flag_readonce) {
-            LED_B_OFF();
-            return;
-        }
-        LED_B_OFF();
-    }
-    */
-
-//    if (userCancelled) {
-//        reply_mix(CMD_ACK, 0xFF, 0, 0, card_data, 0);
-//        switch_off();
-//    } else {
-//        reply_mix(CMD_ACK, result_status, 0, 0, card_data, 0);
-//    }
+    reply_ng(CMD_HF_ICLASS_READER, PM3_SUCCESS, (uint8_t *)&payload, sizeof(iclass_card_select_resp_t));
 
+out:
     switch_off();
 }
 
