@@ -1,10 +1,19 @@
 //-----------------------------------------------------------------------------
-// Jonathan Westhues, split Nov 2006
-// piwi 2018
+// Copyright (C) Jonathan Westhues, Nov 2006
+// Copyright (C) Gerhard de Koning Gans - May 2008
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
 //
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // Routines to support ISO 14443B. This includes both the reader software and
 // the `fake tag' modes.
@@ -194,7 +203,7 @@ static uint32_t iso14b_timeout = FWT_TIMEOUT_14B;
 *
 * Elementary Time Unit (ETU)
 * --------------------------
-* ETU is used to denotate 1 bit period i.e. how long one bit transfer takes.
+* ETU is used to denote 1 bit period i.e. how long one bit transfer takes.
 *
 * - 128 Carrier cycles / 13.56MHz = 8 Subcarrier units / 848kHz = 1/106kHz = 9.4395 µS
 * - 16 Carrier cycles = 1 Subcarrier unit  = 1.17 µS
@@ -203,7 +212,7 @@ static uint32_t iso14b_timeout = FWT_TIMEOUT_14B;
 * ----------
 * 1 ETU =  128 / ( D x fc )
 * where
-*    D = divisor.  Which inital is 1
+*    D = divisor.  Which initial is 1
 *   fc = carrier frequency
 * gives
 *   1 ETU = 128 / fc
@@ -267,7 +276,7 @@ static uint32_t iso14b_timeout = FWT_TIMEOUT_14B;
 * --------------------------
 * The mode FPGA_MAJOR_MODE_HF_SIMULATOR | FPGA_HF_SIMULATOR_MODULATE_BPSK which we use to simulate tag
 * works like this:
-* Simulation per definition is "inversed" effect on the reader antenna.
+* Simulation per definition is "inverted" effect on the reader antenna.
 * - A 1-bit input to the FPGA becomes 8 pulses at 847.5kHz (1.18µS / pulse) == 9.44us
 * - A 0-bit input to the FPGA becomes an unmodulated time of 1.18µS  or does it become 8 nonpulses for 9.44us
 *
@@ -669,7 +678,7 @@ static int GetIso14443bCommandFromReader(uint8_t *received, uint16_t *len) {
     return false;
 }
 
-static void TransmitFor14443b_AsTag(uint8_t *response, uint16_t len) {
+static void TransmitFor14443b_AsTag(const uint8_t *response, uint16_t len) {
 
     // Signal field is off with the appropriate LED
     LED_D_OFF();
