@@ -1,13 +1,19 @@
 //-----------------------------------------------------------------------------
-// Jonathan Westhues, split Nov 2006
-// Modified by Greg Jones, Jan 2009
-// Modified by Adrian Dabrowski "atrox", Mar-Sept 2010,Oct 2011
-// Modified by Christian Herrmann "iceman", 2017, 2020
-// Modified by piwi, Oct 2018
+// Copyright (C) Jonathan Westhues, Nov 2006
+// Copyright (C) Greg Jones, Jan 2009
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
 //
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // Routines to support ISO 15693. This includes both the reader software and
 // the `fake tag' modes.
@@ -134,7 +140,7 @@ static uint8_t encode15_lut[] = {
     0x01  // 00000001
 };
 
-void CodeIso15693AsReader(uint8_t *cmd, int n) {
+void CodeIso15693AsReader(const uint8_t *cmd, int n) {
 
     tosend_reset();
     tosend_t *ts = get_tosend();
@@ -175,7 +181,7 @@ static void CodeIso15693AsReaderEOF(void) {
 // encode data using "1 out of 256" scheme
 // data rate is 1,66 kbit/s (fc/8192)
 // is designed for more robust communication over longer distances
-static void CodeIso15693AsReader256(uint8_t *cmd, int n) {
+static void CodeIso15693AsReader256(const uint8_t *cmd, int n) {
 
     tosend_reset();
     tosend_t *ts = get_tosend();
@@ -212,7 +218,7 @@ static const uint8_t encode_4bits[16] = {
     0xa5, 0x65, 0x95, 0x55
 };
 
-void CodeIso15693AsTag(uint8_t *cmd, size_t len) {
+void CodeIso15693AsTag(const uint8_t *cmd, size_t len) {
     /*
      * SOF comprises 3 parts;
      * * An unmodulated time of 56.64 us
@@ -1454,7 +1460,7 @@ void Iso15693InitReader(void) {
 
 ///////////////////////////////////////////////////////////////////////
 // ISO 15693 Part 3 - Air Interface
-// This section basicly contains transmission and receiving of bits
+// This section basically contains transmission and receiving of bits
 ///////////////////////////////////////////////////////////////////////
 
 // Encode an identify request, which is the first
@@ -1504,7 +1510,7 @@ int SendDataTag(uint8_t *send, int sendlen, bool init, bool speed_fast, uint8_t
 
     } else {
 
-        *eof_time = start_time + 32 * ((8 * ts->max) - 4); // substract the 4 padding bits after EOF
+        *eof_time = start_time + 32 * ((8 * ts->max) - 4); // subtract the 4 padding bits after EOF
         LogTrace_ISO15693(send, sendlen, (start_time * 4), (*eof_time * 4), NULL, true);
         if (recv != NULL) {
             res = GetIso15693AnswerFromTag(recv, max_recv_len, timeout, eof_time);
@@ -1518,7 +1524,7 @@ int SendDataTagEOF(uint8_t *recv, uint16_t max_recv_len, uint32_t start_time, ui
     CodeIso15693AsReaderEOF();
     tosend_t *ts = get_tosend();
     TransmitTo15693Tag(ts->buf, ts->max, &start_time);
-    uint32_t end_time = start_time + 32 * (8 * ts->max - 4); // substract the 4 padding bits after EOF
+    uint32_t end_time = start_time + 32 * (8 * ts->max - 4); // subtract the 4 padding bits after EOF
     LogTrace_ISO15693(NULL, 0, (start_time * 4), (end_time * 4), NULL, true);
 
     int res = 0;
@@ -1858,7 +1864,7 @@ void BruteforceIso15693Afi(uint32_t speed) {
     Iso15693InitReader();
 
     // first without AFI
-    // Tags should respond wihtout AFI and with AFI=0 even when AFI is active
+    // Tags should respond without AFI and with AFI=0 even when AFI is active
 
     data[0] = ISO15_REQ_SUBCARRIER_SINGLE | ISO15_REQ_DATARATE_HIGH | ISO15_REQ_INVENTORY | ISO15_REQINV_SLOT1;
     data[1] = ISO15693_INVENTORY;
@@ -1967,6 +1973,7 @@ void DirectTag15693Command(uint32_t datalen, uint32_t speed, uint32_t recv, uint
         }
     }
     // note: this prevents using hf 15 cmd with s option - which isn't implemented yet anyway
+    // also prevents hf 15 raw -k  keep_field on ...
     FpgaWriteConfWord(FPGA_MAJOR_MODE_OFF);
     LED_D_OFF();
 }
@@ -2087,7 +2094,7 @@ void LockPassSlixIso15693(uint32_t pass_id, uint32_t password) {
 //-----------------------------------------------------------------------------
 
 // Set the UID on Magic ISO15693 tag (based on Iceman's LUA-script).
-void SetTag15693Uid(uint8_t *uid) {
+void SetTag15693Uid(const uint8_t *uid) {
 
     LED_A_ON();
 
@@ -2128,7 +2135,7 @@ void SetTag15693Uid(uint8_t *uid) {
     switch_off();
 }
 
-static void init_password_15693_slixl(uint8_t *buffer, uint8_t *pwd, uint8_t *rnd) {
+static void init_password_15693_slixl(uint8_t *buffer, uint8_t *pwd, const uint8_t *rnd) {
     memcpy(buffer, pwd, 4);
     if (rnd) {
         buffer[0] ^= rnd[0];
