@@ -1,11 +1,18 @@
-﻿//-----------------------------------------------------------------------------
-// Merlok - June 2011, 2012
-// Gerhard de Koning Gans - May 2008
-// Hagen Fritsch - June 2010
+//-----------------------------------------------------------------------------
+// Copyright (C) Gerhard de Koning Gans - May 2008
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
 //
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // Mifare Classic Card Simulation
 //-----------------------------------------------------------------------------
@@ -525,7 +532,7 @@ void Mifare1ksim(uint16_t flags, uint8_t exitAfterNReads, uint8_t *datain, uint1
     int counter = 0;
     bool finished = false;
     bool button_pushed = BUTTON_PRESS();
-    while (!button_pushed && !finished) {
+    while ((button_pushed == false) && (finished == false)) {
 
         WDT_HIT();
 
@@ -897,7 +904,7 @@ void Mifare1ksim(uint16_t flags, uint8_t exitAfterNReads, uint8_t *datain, uint1
                                  response[14], response[15]);
                     }
 
-                    // Access permission managment:
+                    // Access permission management:
                     //
                     // Sector Trailer:
                     // - KEY A access
@@ -907,7 +914,7 @@ void Mifare1ksim(uint16_t flags, uint8_t exitAfterNReads, uint8_t *datain, uint1
                     // Data block:
                     // - Data access
 
-                    // If permission is not allowed, data is cleared (00) in emulator memeory.
+                    // If permission is not allowed, data is cleared (00) in emulator memory.
                     // ex: a0a1a2a3a4a561e789c1b0b1b2b3b4b5 => 00000000000061e789c1b0b1b2b3b4b5
 
 
