@@ -1,9 +1,17 @@
 //-----------------------------------------------------------------------------
-// Copyright (C) 2016 iceman
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
 //
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // Analyse bytes commands
 //-----------------------------------------------------------------------------
@@ -32,10 +40,10 @@
 
 static int CmdHelp(const char *Cmd);
 
-static uint8_t calculateLRC(uint8_t *bytes, uint8_t len) {
+static uint8_t calculateLRC(const uint8_t *d, uint8_t n) {
     uint8_t lcr = 0;
-    for (uint8_t i = 0; i < len; i++)
-        lcr ^= bytes[i];
+    for (uint8_t i = 0; i < n; i++)
+        lcr ^= d[i];
     return lcr;
 }
 /*
@@ -56,7 +64,7 @@ static uint16_t shiftadd ( uint8_t* bytes, uint8_t len){
     return 0;
 }
 */
-static uint16_t calcSumCrumbAdd(uint8_t *bytes, uint8_t len, uint32_t mask) {
+static uint16_t calcSumCrumbAdd(const uint8_t *bytes, uint8_t len, uint32_t mask) {
     uint32_t sum = 0;
     for (uint8_t i = 0; i < len; i++) {
         sum += CRUMB(bytes[i], 0);
@@ -67,10 +75,10 @@ static uint16_t calcSumCrumbAdd(uint8_t *bytes, uint8_t len, uint32_t mask) {
     sum &= mask;
     return (sum & 0xFFFF);
 }
-static uint16_t calcSumCrumbAddOnes(uint8_t *bytes, uint8_t len, uint32_t mask) {
+static uint16_t calcSumCrumbAddOnes(const uint8_t *bytes, uint8_t len, uint32_t mask) {
     return (~calcSumCrumbAdd(bytes, len, mask) & mask);
 }
-static uint16_t calcSumNibbleAdd(uint8_t *bytes, uint8_t len, uint32_t mask) {
+static uint16_t calcSumNibbleAdd(const uint8_t *bytes, uint8_t len, uint32_t mask) {
     uint32_t sum = 0;
     for (uint8_t i = 0; i < len; i++) {
         sum += NIBBLE_LOW(bytes[i]);
@@ -82,7 +90,7 @@ static uint16_t calcSumNibbleAdd(uint8_t *bytes, uint8_t len, uint32_t mask) {
 static uint16_t calcSumNibbleAddOnes(uint8_t *bytes, uint8_t len, uint32_t mask) {
     return (~calcSumNibbleAdd(bytes, len, mask) & mask);
 }
-static uint16_t calcSumCrumbXor(uint8_t *bytes, uint8_t len, uint32_t mask) {
+static uint16_t calcSumCrumbXor(const uint8_t *bytes, uint8_t len, uint32_t mask) {
     uint32_t sum = 0;
     for (uint8_t i = 0; i < len; i++) {
         sum ^= CRUMB(bytes[i], 0);
@@ -93,7 +101,7 @@ static uint16_t calcSumCrumbXor(uint8_t *bytes, uint8_t len, uint32_t mask) {
     sum &= mask;
     return (sum & 0xFFFF);
 }
-static uint16_t calcSumNibbleXor(uint8_t *bytes, uint8_t len, uint32_t mask) {
+static uint16_t calcSumNibbleXor(const uint8_t *bytes, uint8_t len, uint32_t mask) {
     uint32_t sum = 0;
     for (uint8_t i = 0; i < len; i++) {
         sum ^= NIBBLE_LOW(bytes[i]);
@@ -102,7 +110,7 @@ static uint16_t calcSumNibbleXor(uint8_t *bytes, uint8_t len, uint32_t mask) {
     sum &= mask;
     return (sum & 0xFFFF);
 }
-static uint16_t calcSumByteXor(uint8_t *bytes, uint8_t len, uint32_t mask) {
+static uint16_t calcSumByteXor(const uint8_t *bytes, uint8_t len, uint32_t mask) {
     uint32_t sum = 0;
     for (uint8_t i = 0; i < len; i++) {
         sum ^= bytes[i];
@@ -110,7 +118,7 @@ static uint16_t calcSumByteXor(uint8_t *bytes, uint8_t len, uint32_t mask) {
     sum &= mask;
     return (sum & 0xFFFF);
 }
-static uint16_t calcSumByteAdd(uint8_t *bytes, uint8_t len, uint32_t mask) {
+static uint16_t calcSumByteAdd(const uint8_t *bytes, uint8_t len, uint32_t mask) {
     uint32_t sum = 0;
     for (uint8_t i = 0; i < len; i++) {
         sum += bytes[i];
@@ -123,7 +131,7 @@ static uint16_t calcSumByteAddOnes(uint8_t *bytes, uint8_t len, uint32_t mask) {
     return (~calcSumByteAdd(bytes, len, mask) & mask);
 }
 
-static uint16_t calcSumByteSub(uint8_t *bytes, uint8_t len, uint32_t mask) {
+static uint16_t calcSumByteSub(const uint8_t *bytes, uint8_t len, uint32_t mask) {
     uint32_t sum = 0;
     for (uint8_t i = 0; i < len; i++) {
         sum -= bytes[i];
@@ -134,7 +142,7 @@ static uint16_t calcSumByteSub(uint8_t *bytes, uint8_t len, uint32_t mask) {
 static uint16_t calcSumByteSubOnes(uint8_t *bytes, uint8_t len, uint32_t mask) {
     return (~calcSumByteSub(bytes, len, mask) & mask);
 }
-static uint16_t calcSumNibbleSub(uint8_t *bytes, uint8_t len, uint32_t mask) {
+static uint16_t calcSumNibbleSub(const uint8_t *bytes, uint8_t len, uint32_t mask) {
     uint32_t sum = 0;
     for (uint8_t i = 0; i < len; i++) {
         sum -= NIBBLE_LOW(bytes[i]);
@@ -148,7 +156,7 @@ static uint16_t calcSumNibbleSubOnes(uint8_t *bytes, uint8_t len, uint32_t mask)
 }
 
 // BSD shift checksum 8bit version
-static uint16_t calcBSDchecksum8(uint8_t *bytes, uint8_t len, uint32_t mask) {
+static uint16_t calcBSDchecksum8(const uint8_t *bytes, uint8_t len, uint32_t mask) {
     uint32_t sum = 0;
     for (uint8_t i = 0; i < len; i++) {
         sum = ((sum & 0xFF) >> 1) | ((sum & 0x1) << 7);   // rotate accumulator
@@ -159,7 +167,7 @@ static uint16_t calcBSDchecksum8(uint8_t *bytes, uint8_t len, uint32_t mask) {
     return (sum & 0xFFFF);
 }
 // BSD shift checksum 4bit version
-static uint16_t calcBSDchecksum4(uint8_t *bytes, uint8_t len, uint32_t mask) {
+static uint16_t calcBSDchecksum4(const uint8_t *bytes, uint8_t len, uint32_t mask) {
     uint32_t sum = 0;
     for (uint8_t i = 0; i < len; i++) {
         sum = ((sum & 0xF) >> 1) | ((sum & 0x1) << 3);   // rotate accumulator
@@ -979,14 +987,22 @@ static int CmdAnalyseFreq(const char *Cmd) {
     CLIParserContext *ctx;
     CLIParserInit(&ctx, "analyse freq",
                   "calc wave lengths",
-                  "analyse freq"
+                  "analyse freq\n"
+                  ""
                  );
 
     void *argtable[] = {
         arg_param_begin,
+        arg_int0("F", "freq", "<int>", "resonating frequency F in hertz (Hz)"),
+        arg_int0("L", "cap",  "<int>", "capacitance C in micro farads (F)"),
+        arg_int0("C", "ind",  "<int>", "inductance in micro henries (H)"),
         arg_param_end
     };
     CLIExecWithReturn(ctx, Cmd, argtable, true);
+
+    int F = arg_get_int_def(ctx, 1, 0);
+    int L = arg_get_int_def(ctx, 2, 0);
+    int C = arg_get_int_def(ctx, 3, 0);
     CLIParserFree(ctx);
 
     const double c = 299792458;
@@ -1002,6 +1018,35 @@ static int CmdAnalyseFreq(const char *Cmd) {
     PrintAndLogEx(INFO, "   125 kHz has %f m, rf range %f m", len_125, rf_range_125);
     PrintAndLogEx(INFO, "   134 kHz has %f m, rf range %f m", len_134, rf_range_134);
     PrintAndLogEx(INFO, " 13.56 mHz has %f m, rf range %f m", len_1356, rf_range_1356);
+
+
+    if (F == 0 && C == 0 && L == 0)
+        return PM3_SUCCESS;
+
+
+    PrintAndLogEx(INFO, "");
+    PrintAndLogEx(INFO, "Resonant frequency calculator");
+
+    // From  https://goodcalculators.com/resonant-frequency-calculator/
+    // Calc Resonant Frequency [Hz]
+    // f = 1 / (2π √L C)
+    if (F == 0) {
+        double calc_freq = 1 / (2 * M_PI * sqrtf((L * C)));
+        PrintAndLogEx(INFO, "Resonating Frequency  %lf Hz", calc_freq);
+    }
+    // Calc Inductance [H]
+    // L = 1 / (4π2 f2 C)
+    if (L == 0) {
+        double calc_inductance = 1 / (4 * (M_PI * M_PI) * (F * F) * C);
+        PrintAndLogEx(INFO, "Inductance %lf Henries", calc_inductance);
+    }
+
+    // Capacitance [F]
+    //  C = 1 / (4π2 f2 L)
+    if (C == 0) {
+        double calc_capacitance = 1 / (4 * (M_PI * M_PI) * (F * F) * L);
+        PrintAndLogEx(INFO, "Capacitance %lf Farads", calc_capacitance);
+    }
     return PM3_SUCCESS;
 }
 
@@ -1015,7 +1060,7 @@ static int CmdAnalyseFoo(const char *Cmd) {
 
     void *argtable[] = {
         arg_param_begin,
-        arg_strx0("r", "raw",  "<hex>", "raw bytes (strx)"),
+        arg_str1("r", "raw",  "<hex>", "raw bytes"),
         arg_param_end
     };
     CLIExecWithReturn(ctx, Cmd, argtable, false);
@@ -1127,9 +1172,9 @@ static int CmdAnalyseUnits(const char *Cmd) {
         PrintAndLogEx(NORMAL, "");
 
         PrintAndLogEx(INFO, "SSP CLK 3.39MHz to US conversions");
-        PrintAndLogEx(INFO, "  32 SSP = %u US (expext 9 or 10) " _GREEN_("ok"), SSP_TO_US(32));
-        PrintAndLogEx(INFO, " 320 SSP = %u US (expext 94 or 95) " _GREEN_("ok"), SSP_TO_US(320));
-        PrintAndLogEx(INFO, "1024 SSP = %u US (expext 302) " _GREEN_("ok"), SSP_TO_US(1024));
+        PrintAndLogEx(INFO, "  32 SSP = %u US (expect 9 or 10) " _GREEN_("ok"), SSP_TO_US(32));
+        PrintAndLogEx(INFO, " 320 SSP = %u US (expect 94 or 95) " _GREEN_("ok"), SSP_TO_US(320));
+        PrintAndLogEx(INFO, "1024 SSP = %u US (expect 302) " _GREEN_("ok"), SSP_TO_US(1024));
         PrintAndLogEx(NORMAL, "");
 
         PrintAndLogEx(INFO, "ETU to SSP CLK 3.39MHz conversions");
@@ -1144,11 +1189,11 @@ static int CmdAnalyseUnits(const char *Cmd) {
         PrintAndLogEx(INFO, "  32 SSP = %u ETU (expect 1) " _GREEN_("ok"), SSP_TO_ETU(32));
     } else if (etu) {
 
-        PrintAndLogEx(INFO, " %d ETU = %u us ", ETU_TO_US(etu));
-        PrintAndLogEx(INFO, " %d ETU = %u SSP ", ETU_TO_SSP(etu));
+        PrintAndLogEx(INFO, " %d ETU = %u us ", ETU_TO_US(etu), 0);
+        PrintAndLogEx(INFO, " %d ETU = %u SSP ", ETU_TO_SSP(etu), 0);
     } else if (us) {
-        PrintAndLogEx(INFO, " %d us = %u ETU ", US_TO_ETU(us));
-        PrintAndLogEx(INFO, " %d us = %u SSP ", US_TO_SSP(us));
+        PrintAndLogEx(INFO, " %d us = %u ETU ", US_TO_ETU(us), 0);
+        PrintAndLogEx(INFO, " %d us = %u SSP ", US_TO_SSP(us), 0);
     }
 
     return PM3_SUCCESS;
