@@ -1,9 +1,17 @@
 //-----------------------------------------------------------------------------
-// Copyright (C) 2015 Piwi
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
 //
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // High frequency Topaz (NFC Type 1) commands
 //-----------------------------------------------------------------------------
@@ -23,6 +31,7 @@
 #include "crc16.h"
 #include "protocols.h"
 #include "nfc/ndef.h"
+#include "fileutils.h"     // saveFile
 
 #define TOPAZ_STATIC_MEMORY (0x0f * 8)  // 15 blocks with 8 Bytes each
 
@@ -40,8 +49,8 @@ static struct {
     uint8_t uid[7];
     uint16_t size;
     uint8_t data_blocks[TOPAZ_STATIC_MEMORY / 8][8]; // this memory is always there
-    uint8_t *dynamic_memory;                       // this memory can be there
-    dynamic_lock_area_t *dynamic_lock_areas;       // lock area descriptors
+    uint8_t *dynamic_memory;                         // this memory can be there
+    dynamic_lock_area_t *dynamic_lock_areas;         // lock area descriptors
 } topaz_tag;
 
 static void topaz_switch_on_field(void) {
@@ -192,6 +201,11 @@ static bool topaz_byte_is_locked(uint16_t byteno) {
         if (lock_area == NULL) {
             return false;
         } else {
+
+            if ((lock_area->byte_offset - TOPAZ_STATIC_MEMORY) < 0) {
+                return false;
+            }
+
             lockbits = &topaz_tag.dynamic_memory[lock_area->byte_offset - TOPAZ_STATIC_MEMORY];
             locked_bytes_per_bit = lock_area->bytes_locked_per_bit;
             byteno = byteno - lock_area->first_locked_byte;
@@ -388,10 +402,6 @@ static void topaz_print_lifecycle_state(uint8_t *data) {
     // to be done
 }
 
-static int topaz_print_NDEF(uint8_t *data, size_t maxsize) {
-    return NDEFDecodeAndPrint(data, maxsize, true);
-}
-
 static int CmdHFTopazReader(const char *Cmd) {
     CLIParserContext *ctx;
     CLIParserInit(&ctx, "hf topaz reader",
@@ -417,16 +427,22 @@ int CmdHFTopazInfo(const char *Cmd) {
     CLIParserContext *ctx;
     CLIParserInit(&ctx, "hf topaz info",
                   "Get info from Topaz tags",
-                  "hf topaz info");
+                  "hf topaz info\n"
+                  "hf topaz info -f myfilename -> save raw NDEF to file\n"
+                 );
 
     void *argtable[] = {
         arg_param_begin,
+        arg_str0("f", "file", "<fn>", "save raw NDEF to file"),
         arg_lit0("v", "verbose", "verbose output"),
         arg_param_end
     };
     CLIExecWithReturn(ctx, Cmd, argtable, true);
 
-    bool verbose = arg_get_lit(ctx, 1);
+    int fnlen = 0;
+    char filename[FILE_PATH_SIZE] = {0};
+    CLIParamStrToBuf(arg_get_str(ctx, 1), (uint8_t *)filename, FILE_PATH_SIZE, &fnlen);
+    bool verbose = arg_get_lit(ctx, 2);
 
     CLIParserFree(ctx);
 
@@ -482,7 +498,10 @@ int CmdHFTopazInfo(const char *Cmd) {
 
     topaz_print_lifecycle_state(&topaz_tag.data_blocks[1][0]);
 
-    topaz_print_NDEF(&topaz_tag.data_blocks[1][0], TOPAZ_STATIC_MEMORY);
+    if (fnlen != 0) {
+        saveFile(filename, ".bin", &topaz_tag.data_blocks[1][0], TOPAZ_STATIC_MEMORY);
+    }
+    NDEFDecodeAndPrint(&topaz_tag.data_blocks[1][0], TOPAZ_STATIC_MEMORY, true);
 
     PrintAndLogEx(INFO, "-------------------------------------------------------------");
     topaz_switch_off_field();
