@@ -1,4 +1,18 @@
 //-----------------------------------------------------------------------------
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
+//
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
+//-----------------------------------------------------------------------------
 // Waveshare commands
 //-----------------------------------------------------------------------------
 // from ST25R3911B-NFC-Demo source code by Waveshare team
@@ -159,7 +173,8 @@ static int read_bmp_bitmap(const uint8_t *bmp, const size_t bmpsize, uint8_t mod
     return PM3_SUCCESS;
 }
 
-static void rgb_to_gray(int16_t *chanR, int16_t *chanG, int16_t *chanB, uint16_t width, uint16_t height, int16_t *chanGrey) {
+static void rgb_to_gray(const int16_t *chanR, const int16_t *chanG, const int16_t *chanB,
+                        uint16_t width, uint16_t height, int16_t *chanGrey) {
     for (uint16_t Y = 0; Y < height; Y++) {
         for (uint16_t X = 0; X < width; X++) {
             // greyscale conversion
@@ -179,7 +194,7 @@ static void dither_chan_inplace(int16_t *chan, uint16_t width, uint16_t height)
             int16_t newp = oldp > 127 ? 255 : 0;
             chan[X + Y * width] = newp;
             int16_t err = oldp - newp;
-            float m[] = {7, 3, 5, 1};
+            const float m[] = {7, 3, 5, 1};
             if (X < width - 1) {
                 chan[X + 1 +  Y      * width] = chan[X + 1 +  Y      * width] + m[0] / 16 * err;
             }
@@ -204,7 +219,8 @@ static uint32_t color_compare(int16_t r1, int16_t g1, int16_t b1, int16_t r2, in
     return dist;
 }
 
-static void nearest_color(int16_t oldR, int16_t oldG, int16_t oldB, uint8_t *palette, uint16_t palettelen, uint8_t *newR, uint8_t *newG, uint8_t *newB) {
+static void nearest_color(int16_t oldR, int16_t oldG, int16_t oldB, const uint8_t *palette,
+                          uint16_t palettelen, uint8_t *newR, uint8_t *newG, uint8_t *newB) {
     uint32_t bestdist = 0x7FFFFFFF;
     for (uint16_t i = 0; i < palettelen; i++) {
         uint8_t R = palette[i * 3 + 0];
@@ -239,7 +255,7 @@ static void dither_rgb_inplace(int16_t *chanR, int16_t *chanG, int16_t *chanB, u
             int16_t errR = oldR - newR;
             int16_t errG = oldG - newG;
             int16_t errB = oldB - newB;
-            float m[] = {7, 3, 5, 1};
+            const float m[] = {7, 3, 5, 1};
             if (Y % 2) {
                 if (XX > 0) {
                     chanR[XX - 1 +  Y      * width] = (chanR[XX - 1 +  Y      * width] + m[0] / 16 * errR);
@@ -296,7 +312,7 @@ static void rgb_to_gray_red_inplace(int16_t *chanR, int16_t *chanG, int16_t *cha
     }
 }
 
-static void threshold_chan(int16_t *colorchan, uint16_t width, uint16_t height, uint8_t threshold, uint8_t *colormap) {
+static void threshold_chan(const int16_t *colorchan, uint16_t width, uint16_t height, uint8_t threshold, uint8_t *colormap) {
     for (uint16_t Y = 0; Y < height; Y++) {
         for (uint16_t X = 0; X < width; X++) {
             colormap[X + Y * width] = colorchan[X + Y * width] < threshold;
@@ -304,7 +320,9 @@ static void threshold_chan(int16_t *colorchan, uint16_t width, uint16_t height,
     }
 }
 
-static void threshold_rgb_black_red(int16_t *chanR, int16_t *chanG, int16_t *chanB, uint16_t width, uint16_t height, uint8_t threshold_black, uint8_t threshold_red, uint8_t *blackmap, uint8_t *redmap) {
+static void threshold_rgb_black_red(const int16_t *chanR, const int16_t *chanG, const int16_t *chanB,
+                                    uint16_t width, uint16_t height, uint8_t threshold_black,
+                                    uint8_t threshold_red, uint8_t *blackmap, uint8_t *redmap) {
     for (uint16_t Y = 0; Y < height; Y++) {
         for (uint16_t X = 0; X < width; X++) {
             if ((chanR[X + Y * width] < threshold_black) && (chanG[X + Y * width] < threshold_black) && (chanB[X + Y * width] < threshold_black)) {
@@ -321,7 +339,7 @@ static void threshold_rgb_black_red(int16_t *chanR, int16_t *chanG, int16_t *cha
     }
 }
 
-static void map8to1(uint8_t *colormap, uint16_t width, uint16_t height, uint8_t *colormap8) {
+static void map8to1(const uint8_t *colormap, uint16_t width, uint16_t height, uint8_t *colormap8) {
     uint16_t width8;
     if (width % 8 == 0) {
         width8 = width / 8;
@@ -532,12 +550,12 @@ static int read_bmp_rgb(uint8_t *bmp, const size_t bmpsize, uint8_t model_nr, ui
     return PM3_SUCCESS;
 }
 
-static void read_black(uint32_t i, uint8_t *l, uint8_t model_nr, uint8_t *black) {
+static void read_black(uint32_t i, uint8_t *l, uint8_t model_nr, const uint8_t *black) {
     for (uint8_t j = 0; j < models[model_nr].len; j++) {
         l[3 + j] = black[i * models[model_nr].len + j];
     }
 }
-static void read_red(uint32_t i, uint8_t *l, uint8_t model_nr, uint8_t *red) {
+static void read_red(uint32_t i, uint8_t *l, uint8_t model_nr, const uint8_t *red) {
     // spurious warning with GCC10 (-Wstringop-overflow) when j is uint8_t, even if all len are < 128
     for (uint16_t j = 0; j < models[model_nr].len; j++) {
         if (model_nr == M1in54B) {
@@ -593,7 +611,7 @@ static int start_drawing_1in54B(uint8_t model_nr, uint8_t *black, uint8_t *red)
     uint8_t step_4[2] = {0xcd, 0x04};
     uint8_t step_6[2] = {0xcd, 0x06};
     uint8_t rx[20] = {0};
-    uint16_t actrxlen[20], i = 0, progress = 0;
+    uint16_t actrxlen[20], i, progress;
 
     if (model_nr == M1in54B) {
         step_5[2] = 100;
@@ -616,6 +634,7 @@ static int start_drawing_1in54B(uint8_t model_nr, uint8_t *black, uint8_t *red)
     if (ret != PM3_SUCCESS) {
         return ret;
     }
+
     PrintAndLogEx(DEBUG, "1.54_Step7: e-paper config2 (red)");
     if (model_nr == M1in54B) {       //1.54inch B Keychain
         for (i = 0; i < 50; i++) {
@@ -635,12 +654,13 @@ static int start_drawing_1in54B(uint8_t model_nr, uint8_t *black, uint8_t *red)
     if (ret != PM3_SUCCESS) {
         return ret;
     }
+
     PrintAndLogEx(DEBUG, "1.54_Step9");
     return PM3_SUCCESS;
 }
 
 static int start_drawing(uint8_t model_nr, uint8_t *black, uint8_t *red) {
-    uint8_t progress = 0;
+    uint8_t progress;
     uint8_t step0[2] = {0xcd, 0x0d};
     uint8_t step1[3] = {0xcd, 0x00, 10};  // select e-paper type and reset e-paper
     //  4 :2.13inch e-Paper
@@ -667,14 +687,12 @@ static int start_drawing(uint8_t model_nr, uint8_t *black, uint8_t *red) {
 // uint8_t step13[2]={0xcd,0x0b};     // Judge whether the power supply is turned off successfully
 // uint8_t step14[2]={0xcd,0x0c};     // The end of the transmission
     uint8_t rx[20];
-    uint16_t actrxlen[20], i = 0;
-
-
+    uint16_t actrxlen[20], i;
 
     clearCommandBuffer();
     SendCommandMIX(CMD_HF_ISO14443A_READER, ISO14A_CONNECT | ISO14A_NO_DISCONNECT, 0, 0, NULL, 0);
     PacketResponseNG resp;
-    if (!WaitForResponseTimeout(CMD_ACK, &resp, 2500)) {
+    if (WaitForResponseTimeout(CMD_ACK, &resp, 2500) == false) {
         PrintAndLogEx(ERR, "No tag found");
         DropField();
         return PM3_ETIMEOUT;
@@ -711,40 +729,41 @@ static int start_drawing(uint8_t model_nr, uint8_t *black, uint8_t *red) {
         return PM3_ESOFT;
     }
     PrintAndLogEx(DEBUG, "model_nr = %d", model_nr);
-    int ret;
+
     PrintAndLogEx(DEBUG, "Step0");
-    ret = transceive_blocking(step0, 2, rx, 20, actrxlen, true);  //cd 0d
+    int ret = transceive_blocking(step0, 2, rx, 20, actrxlen, true);  //cd 0d
     if (ret != PM3_SUCCESS) {
         return ret;
     }
+
     PrintAndLogEx(DEBUG, "Step1: e-paper config");
-    //step1[2] screen model
-    //step8[2] nr of bytes sent at once
-    //step13[2] nr of bytes sent for the second time
+    // step1[2] screen model
+    // step8[2] nr of bytes sent at once
+    // step13[2] nr of bytes sent for the second time
     // generally, step8 sends a black image, step13 sends a red image
-    if (model_nr == M2in13) {        //2.13inch
+    if (model_nr == M2in13) {        // 2.13inch
         step1[2] = EPD_2IN13V2;
         step8[2] = 16;
         step13[2] = 0;
-    } else if (model_nr == M2in9) {  //2.9inch
+    } else if (model_nr == M2in9) {  // 2.9inch
         step1[2] = EPD_2IN9;
         step8[2] = 16;
         step13[2] = 0;
-    } else if (model_nr == M4in2) {  //4.2inch
+    } else if (model_nr == M4in2) {  // 4.2inch
         step1[2] = EPD_4IN2;
         step8[2] = 100;
         step13[2] = 0;
-    } else if (model_nr == M7in5) {  //7.5inch
+    } else if (model_nr == M7in5) {  // 7.5inch
         step1[2] = EPD_7IN5V2;
         step8[2] = 120;
         step13[2] = 0;
-    } else if (model_nr == M2in7) {  //2.7inch
+    } else if (model_nr == M2in7) {  // 2.7inch
         step1[2] = EPD_2IN7;
         step8[2] = 121;
         // Send blank data for the first time, and send other data to 0xff without processing the bottom layer
         step13[2] = 121;
-        //Sending the second data is the real image data. If the previous 0xff is not sent, the last output image is abnormally black
-    } else if (model_nr == M2in13B) {  //2.13inch B
+        // Sending the second data is the real image data. If the previous 0xff is not sent, the last output image is abnormally black
+    } else if (model_nr == M2in13B) {  // 2.13inch B
         step1[2] = EPD_2IN13BC;
         step8[2] = 106;
         step13[2] = 106;
@@ -755,31 +774,35 @@ static int start_drawing(uint8_t model_nr, uint8_t *black, uint8_t *red) {
     }
 
     if (model_nr == M1in54B) {
-        ret = transceive_blocking(step1, 2, rx, 20, actrxlen, true);  //cd 00
+        ret = transceive_blocking(step1, 2, rx, 20, actrxlen, true);  // cd 00
     } else {
         ret = transceive_blocking(step1, 3, rx, 20, actrxlen, true);
     }
     if (ret != PM3_SUCCESS) {
         return ret;
     }
+
     msleep(100);
     PrintAndLogEx(DEBUG, "Step2: e-paper normal mode type");
-    ret = transceive_blocking(step2, 2, rx, 20, actrxlen, true);   //cd 01
+    ret = transceive_blocking(step2, 2, rx, 20, actrxlen, true);  // cd 01
     if (ret != PM3_SUCCESS) {
         return ret;
     }
+
     msleep(100);
     PrintAndLogEx(DEBUG, "Step3: e-paper config1");
-    ret = transceive_blocking(step3, 2, rx, 20, actrxlen, true); //cd 02
+    ret = transceive_blocking(step3, 2, rx, 20, actrxlen, true); // cd 02
     if (ret != PM3_SUCCESS) {
         return ret;
     }
+
     msleep(200);
     PrintAndLogEx(DEBUG, "Step4: e-paper power on");
-    ret = transceive_blocking(step4, 2, rx, 20, actrxlen, true); //cd 03
+    ret = transceive_blocking(step4, 2, rx, 20, actrxlen, true); // cd 03
     if (ret != PM3_SUCCESS) {
         return ret;
     }
+
     if (model_nr == M1in54B) {
         // 1.54B Keychain handler
         PrintAndLogEx(DEBUG, "Start_Drawing_1in54B");
@@ -787,27 +810,27 @@ static int start_drawing(uint8_t model_nr, uint8_t *black, uint8_t *red) {
         if (ret != PM3_SUCCESS) {
             return ret;
         }
-        //1.54B Data transfer is complete and wait for refresh
+        // 1.54B Data transfer is complete and wait for refresh
     } else {
         PrintAndLogEx(DEBUG, "Step5: e-paper config2");
-        ret = transceive_blocking(step5, 2, rx, 20, actrxlen, true);   //cd 05
+        ret = transceive_blocking(step5, 2, rx, 20, actrxlen, true); // cd 05
         if (ret != PM3_SUCCESS) {
             return ret;
         }
         msleep(100);
         PrintAndLogEx(DEBUG, "Step6: EDP load to main") ;
-        ret = transceive_blocking(step6, 2, rx, 20, actrxlen, true); //cd 06
+        ret = transceive_blocking(step6, 2, rx, 20, actrxlen, true); // cd 06
         if (ret != PM3_SUCCESS) {
             return ret;
         }
         msleep(100);
         PrintAndLogEx(DEBUG, "Step7: Data preparation");
-        ret = transceive_blocking(step7, 2, rx, 20, actrxlen, true); //cd 07
+        ret = transceive_blocking(step7, 2, rx, 20, actrxlen, true); // cd 07
         if (ret != PM3_SUCCESS) {
             return ret;
         }
         PrintAndLogEx(DEBUG, "Step8: Start data transfer");
-        if (model_nr == M2in13) {      //2.13inch
+        if (model_nr == M2in13) {      // 2.13inch
             for (i = 0; i < 250; i++) {
                 read_black(i, step8, model_nr, black);
                 ret = transceive_blocking(step8, 19, rx, 20, actrxlen, true); // cd 08
@@ -939,6 +962,7 @@ static int start_drawing(uint8_t model_nr, uint8_t *black, uint8_t *red) {
     } else if (model_nr == M7in5HD) {
         msleep(1000);
     }
+
     uint8_t fail_num = 0;
     while (1) {
         if (model_nr == M1in54B) {
@@ -1006,7 +1030,7 @@ static int CmdHF14AWSLoadBmp(const char *Cmd) {
         arg_param_begin,
         arg_int1("m", NULL, "<nr>", modeldesc),
         arg_lit0("s", "save", "save dithered version in filename-[n].bmp, only for RGB BMP"),
-        arg_str1("f", "file", "<filename>", "filename[.bmp] to upload to tag"),
+        arg_str1("f", "file", "<fn>", "specify filename[.bmp] to upload to tag"),
         arg_param_end
     };
 
