@@ -1,11 +1,19 @@
 //-----------------------------------------------------------------------------
-// Copyright (C) 2010 iZsh <izsh at fail0verflow.com>
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
 //
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
-// Low frequency EM4x commands
+// Low frequency EM4x05 commands
 //-----------------------------------------------------------------------------
 
 #include "cmdlfem4x05.h"
@@ -74,7 +82,7 @@ static const char *em_get_card_str(uint32_t config) {
 }
 
 // even parity COLUMN
-static bool em4x05_col_parity_test(uint8_t *bs, size_t size, uint8_t rows, uint8_t cols, uint8_t pType) {
+static bool em4x05_col_parity_test(const uint8_t *bs, size_t size, uint8_t rows, uint8_t cols, uint8_t pType) {
     if (rows * cols > size) return false;
     uint8_t colP = 0;
 
@@ -572,7 +580,7 @@ int CmdEM4x05Dump(const char *Cmd) {
     if (card_type == EM_4205 || card_type == EM_4305 || card_type == EM_UNKNOWN) {
         bool lockInPW2 = false;
         // To flag any blocks locked we need to read blocks 14 and 15 first
-        // dont swap endian until we get block lock flags.
+        // don't swap endian until we get block lock flags.
         int status14 = em4x05_read_word_ext(EM4305_PROT1_BLOCK, pwd, usePwd, &word);
         if (status14 == PM3_SUCCESS) {
             if ((word & 0x00008000) != 0x00) {
@@ -643,7 +651,7 @@ int CmdEM4x05Dump(const char *Cmd) {
     } else if (card_type == EM_4369 || card_type == EM_4469) {
 
         // To flag any blocks locked we need to read block 3 first
-        // dont swap endian until we get block lock flags.
+        // don't swap endian until we get block lock flags.
         int status14 = em4x05_read_word_ext(EM4469_PROT_BLOCK, pwd, usePwd, &word);
         if (status14 == PM3_SUCCESS) {
             lock_bits = word;
@@ -1579,7 +1587,7 @@ int CmdEM4x05Unlock(const char *Cmd) {
     uint32_t search_value = 0;
     uint32_t write_value = 0;
     //
-    // inital phase
+    // initial phase
     //
     // read word 14
     uint32_t init_14 = 0;
@@ -1889,7 +1897,7 @@ int CmdEM4x05Unlock(const char *Cmd) {
     return exit_code;
 }
 
-static size_t em4x05_Sniff_GetNextBitStart(size_t idx, size_t sc, int *data, size_t *pulsesamples) {
+static size_t em4x05_Sniff_GetNextBitStart(size_t idx, size_t sc, const int *data, size_t *pulsesamples) {
     while ((idx < sc) && (data[idx] <= 10)) // find a going high
         idx++;
 
@@ -1905,7 +1913,7 @@ static size_t em4x05_Sniff_GetNextBitStart(size_t idx, size_t sc, int *data, siz
     return idx;
 }
 
-uint32_t static em4x05_Sniff_GetBlock(char *bits, bool fwd) {
+static uint32_t em4x05_Sniff_GetBlock(const char *bits, bool fwd) {
     uint32_t value = 0;
     uint8_t idx;
     bool parityerror = false;
