@@ -1,9 +1,17 @@
 //-----------------------------------------------------------------------------
-// Iceman, 2019
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
 //
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // Low frequency Motorola tag commands
 // PSK1, RF/32, 64 bits long,  at 74 kHz
@@ -153,8 +161,8 @@ static int CmdMotorolaReader(const char *Cmd) {
         PrintAndLogEx(INFO, "Press " _GREEN_("<Enter>") " to exit");
     }
 
-    // Motorola Flexpass seem to work at 74 kHz
-    // and take about 4400 samples to befor modulating
+    // Motorola Flexpass seems to work at 74 kHz
+    // and take about 4400 samples too before modulating
     sample_config sc = {
         .decimation = -1,
         .bits_per_sample = -1,
@@ -193,7 +201,7 @@ static int CmdMotorolaClone(const char *Cmd) {
 
     void *argtable[] = {
         arg_param_begin,
-        arg_strx1("r", "raw", "<hex>", "raw hex bytes. 8 bytes"),
+        arg_str1("r", "raw", "<hex>", "raw hex bytes. 8 bytes"),
         arg_lit0(NULL, "q5", "optional - specify writing to Q5/T5555 tag"),
         arg_lit0(NULL, "em", "optional - specify writing to EM4305/4469 tag"),
         arg_param_end
