@@ -1,8 +1,17 @@
 //-----------------------------------------------------------------------------
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
 //
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // Low frequency visa 2000 tag commands
 // by iceman
@@ -44,12 +53,11 @@ static uint8_t visa_chksum(uint32_t id) {
 
 static uint8_t visa_parity(uint32_t id) {
     // 4bit parity LUT
-    uint8_t par_lut[] = {
-        0, 1, 1, 0
-        , 1, 0, 0, 1
-        , 1, 0, 0, 1
-        , 0, 1, 1, 0
+    const uint8_t par_lut[] = {
+        0, 1, 1, 0, 1, 0, 0, 1,
+        1, 0, 0, 1, 0, 1, 1, 0
     };
+
     uint8_t par = 0;
     par |= par_lut[(id >> 28) & 0xF ] << 7;
     par |= par_lut[(id >> 24) & 0xF ] << 6;
