@@ -1,7 +1,17 @@
 //-----------------------------------------------------------------------------
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
+//
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // NFC commands
 //-----------------------------------------------------------------------------
@@ -19,6 +29,7 @@
 #include "cmdhfthinfilm.h"
 #include "cmdhftopaz.h"
 #include "cmdnfc.h"
+#include "fileutils.h"
 
 void print_type4_cc_info(uint8_t *d, uint8_t n) {
     if (n < 0x0F) {
@@ -60,14 +71,17 @@ static int CmdNfcDecode(const char *Cmd) {
 
     CLIParserContext *ctx;
     CLIParserInit(&ctx, "nfc decode",
-                  "Decode and print NFC Data Exchange Format (NDEF)",
+                  "Decode and print NFC Data Exchange Format (NDEF)\n"
+                  "You must provide either data in hex or a filename, but not both",
                   "nfc decode -d 9101085402656e48656c6c6f5101085402656e576f726c64\n"
                   "nfc decode -d 0103d020240203e02c040300fe\n"
+                  "nfc decode -f myfilename"
                  );
 
     void *argtable[] = {
         arg_param_begin,
-        arg_strx0("d",  "data", "<hex>", "NDEF data to decode"),
+        arg_str0("d",  "data", "<hex>", "NDEF data to decode"),
+        arg_str0("f", "file", "<fn>", "file to load"),
         arg_lit0("v",  "verbose", "verbose mode"),
         arg_param_end
     };
@@ -76,16 +90,59 @@ static int CmdNfcDecode(const char *Cmd) {
     int datalen = 0;
     uint8_t data[MAX_NDEF_LEN] = {0};
     CLIGetHexWithReturn(ctx, 1, data, &datalen);
-    bool verbose = arg_get_lit(ctx, 2);
 
+    int fnlen = 0;
+    char filename[FILE_PATH_SIZE] = {0};
+    CLIParamStrToBuf(arg_get_str(ctx, 2), (uint8_t *)filename, FILE_PATH_SIZE, &fnlen);
+
+    bool verbose = arg_get_lit(ctx, 3);
     CLIParserFree(ctx);
-    if (datalen == 0)
+    if (((datalen != 0) && (fnlen != 0)) || ((datalen == 0) && (fnlen == 0))) {
+        PrintAndLogEx(ERR, "You must provide either data in hex or a filename");
         return PM3_EINVARG;
+    }
+    int res = PM3_SUCCESS;
+    if (fnlen != 0) {
 
-    int res = NDEFDecodeAndPrint(data, datalen, verbose);
-    if (res != PM3_SUCCESS) {
-        PrintAndLogEx(INFO, "Trying to parse NDEF records w/o NDEF header");
-        res = NDEFRecordsDecodeAndPrint(data, datalen);
+        uint8_t *dump = NULL;
+        size_t bytes_read = 4096;
+        DumpFileType_t dftype = getfiletype(filename);
+        switch (dftype) {
+            case BIN: {
+                res = loadFile_safe(filename, ".bin", (void **)&dump, &bytes_read);
+                break;
+            }
+            case EML: {
+                res = loadFileEML_safe(filename, (void **)&dump, &bytes_read);
+                break;
+            }
+            case JSON:
+            case DICTIONARY: {
+                free(dump);
+                PrintAndLogEx(ERR, "Error: Only BIN/EML formats allowed");
+                return PM3_EINVARG;
+            }
+        }
+
+        if (res != PM3_SUCCESS) {
+            PrintAndLogEx(ERR, "error, something went wrong when loading file");
+            free(dump);
+            return PM3_EFILE;
+        }
+
+
+        res = NDEFDecodeAndPrint(dump, bytes_read, verbose);
+        if (res != PM3_SUCCESS) {
+            PrintAndLogEx(INFO, "Trying to parse NDEF records w/o NDEF header");
+            res = NDEFRecordsDecodeAndPrint(dump, bytes_read);
+        }
+        free(dump);
+    } else {
+        res = NDEFDecodeAndPrint(data, datalen, verbose);
+        if (res != PM3_SUCCESS) {
+            PrintAndLogEx(INFO, "Trying to parse NDEF records w/o NDEF header");
+            res = NDEFRecordsDecodeAndPrint(data, datalen);
+        }
     }
     return res;
 }
