@@ -1,10 +1,17 @@
 //-----------------------------------------------------------------------------
-// Copyright (C) 2018, 2021 Merlok
-// Copyright (C) 2018 drHatson
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
 //
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // crypto commands
 //-----------------------------------------------------------------------------
@@ -585,7 +592,7 @@ exit:
     return res;
 }
 
-void bin_xor(uint8_t *d1, uint8_t *d2, size_t len) {
+void bin_xor(uint8_t *d1, const uint8_t *d2, size_t len) {
     for (size_t i = 0; i < len; i++)
         d1[i] = d1[i] ^ d2[i];
 }
@@ -598,7 +605,7 @@ void AddISO9797M2Padding(uint8_t *ddata, size_t *ddatalen, uint8_t *sdata, size_
     ddata[sdatalen] = ISO9797_M2_PAD_BYTE;
 }
 
-size_t FindISO9797M2PaddingDataLen(uint8_t *data, size_t datalen) {
+size_t FindISO9797M2PaddingDataLen(const uint8_t *data, size_t datalen) {
     for (int i = datalen; i > 0; i--) {
         if (data[i - 1] == 0x80)
             return i - 1;
