@@ -1,9 +1,17 @@
 //-----------------------------------------------------------------------------
-// Copyright (C) 2017 Merlok
-// modified 2017 iceman
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
+//
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // EMV commands
 //-----------------------------------------------------------------------------
@@ -81,10 +89,10 @@ static int CmdEMVSelect(const char *Cmd) {
         arg_param_begin,
         arg_lit0("sS",  "select",  "activate field and select card"),
         arg_lit0("kK",  "keep",    "keep field for next command"),
-        arg_lit0("aA",  "apdu",    "show APDU reqests and responses"),
+        arg_lit0("aA",  "apdu",    "show APDU requests and responses"),
         arg_lit0("tT",  "tlv",     "TLV decode results"),
         arg_lit0("wW",  "wired",   "Send data via contact (iso7816) interface. Contactless interface set by default."),
-        arg_strx0(NULL,  NULL,     "<HEX applet AID>", NULL),
+        arg_str1(NULL, NULL, "<hex>", "Applet AID"),
         arg_param_end
     };
     CLIExecWithReturn(ctx, Cmd, argtable, true);
@@ -247,7 +255,7 @@ static int CmdEMVGPO(const char *Cmd) {
         arg_lit0("aA",  "apdu",    "show APDU reqests and responses"),
         arg_lit0("tT",  "tlv",     "TLV decode results of selected applets"),
         arg_lit0("wW",  "wired",   "Send data via contact (iso7816) interface. Contactless interface set by default."),
-        arg_strx0(NULL,  NULL,     "<HEX PDOLdata/PDOL>", NULL),
+        arg_strx0(NULL,  NULL,     "<hex>", "PDOLdata/PDOL"),
         arg_param_end
     };
     CLIExecWithReturn(ctx, Cmd, argtable, true);
@@ -354,7 +362,7 @@ static int CmdEMVReadRecord(const char *Cmd) {
         arg_lit0("aA",  "apdu",    "show APDU reqests and responses"),
         arg_lit0("tT",  "tlv",     "TLV decode results of selected applets"),
         arg_lit0("wW",  "wired",   "Send data via contact (iso7816) interface. Contactless interface set by default."),
-        arg_strx1(NULL,  NULL,     "<SFI 1byte HEX><SFIrecord 1byte HEX>", NULL),
+        arg_strx1(NULL,  NULL,     "<hex>", "<SFI 1 byte><SFIrecord 1 byte"),
         arg_param_end
     };
     CLIExecWithReturn(ctx, Cmd, argtable, true);
@@ -418,7 +426,7 @@ static int CmdEMVAC(const char *Cmd) {
         arg_lit0("aA",  "apdu",     "show APDU reqests and responses"),
         arg_lit0("tT",  "tlv",      "TLV decode results of selected applets"),
         arg_lit0("wW",  "wired",   "Send data via contact (iso7816) interface. Contactless interface set by default."),
-        arg_strx1(NULL,  NULL,      "<HEX CDOLdata/CDOL>", NULL),
+        arg_strx1(NULL,  NULL,      "<hex>", "CDOLdata/CDOL"),
         arg_param_end
     };
     CLIExecWithReturn(ctx, Cmd, argtable, false);
@@ -528,7 +536,7 @@ static int CmdEMVGenerateChallenge(const char *Cmd) {
                   "Executes Generate Challenge command. It returns 4 or 8-byte random number from card.\n"
                   "Needs a EMV applet to be selected and GPO to be executed.",
                   "emv challenge     -> get challenge\n"
-                  "emv challenge -k  -> get challenge, keep fileld ON\n");
+                  "emv challenge -k  -> get challenge, keep filled ON\n");
 
     void *argtable[] = {
         arg_param_begin,
@@ -590,7 +598,7 @@ static int CmdEMVInternalAuthenticate(const char *Cmd) {
         arg_lit0("aA",  "apdu",    "show APDU reqests and responses"),
         arg_lit0("tT",  "tlv",     "TLV decode results of selected applets"),
         arg_lit0("wW",  "wired",   "Send data via contact (iso7816) interface. Contactless interface set by default."),
-        arg_strx1(NULL,  NULL,     "<HEX DDOLdata/DDOL>", NULL),
+        arg_strx1(NULL,  NULL,     "<hex>", "DDOLdata/DDOL"),
         arg_param_end
     };
     CLIExecWithReturn(ctx, Cmd, argtable, false);
@@ -1365,13 +1373,13 @@ static int CmdEMVExec(const char *Cmd) {
                 }
                 PrintAndLogEx(NORMAL, "raw ARPC: %s", sprint_hex(rawARPC, rawARPClen));
 
-                // here must be calculation of ARPC, but we dont know a bank keys.
+                // here must be calculation of ARPC, but we don't know a bank keys.
                 PrintAndLogEx(NORMAL, "ARPC: n/a");
 
             } else {
                 PrintAndLogEx(WARNING, "Application Cryptogram (AC) not found.");
             }
-            // here must be external authenticate, but we dont know ARPC
+            // here must be external authenticate, but we don't know ARPC
         }
 
         // needs to send AC2 command (res == ARQC)
@@ -1386,7 +1394,7 @@ static int CmdEMVExec(const char *Cmd) {
 
             PrintAndLogEx(NORMAL, "CDOL2 data[%zu]: %s", cdol2_data_tlv->len, sprint_hex(cdol2_data_tlv->value, cdol2_data_tlv->len));
             //PrintAndLogEx(NORMAL, "* * AC2");
-            // here must be AC2, but we dont make external authenticate (
+            // here must be AC2, but we don't make external authenticate (
             /*          // AC2
                         PRINT_INDENT(level);
                         if ((CID & EMVAC_AC2_MASK) == EMVAC_AAC2)     PrintAndLogEx(NORMAL, "\tAC2: AAC (Transaction declined)");
@@ -1442,7 +1450,7 @@ static int CmdEMVScan(const char *Cmd) {
         arg_lit0("gG",  "acgpo",    "VISA. generate AC from GPO."),
         arg_lit0("mM",  "merge",    "Merge output file with card's data. (warning: the file may be corrupted!)"),
         arg_lit0("wW",  "wired",    "Send data via contact (iso7816) interface. Contactless interface set by default."),
-        arg_str1(NULL,  NULL,       "output.json", "JSON output file name"),
+        arg_str1(NULL,  NULL,       "<fn>", "JSON output filename"),
         arg_param_end
     };
     CLIExecWithReturn(ctx, Cmd, argtable, true);
