@@ -1,10 +1,17 @@
 //-----------------------------------------------------------------------------
-// Copyright (C) 2018 Merlok
-// Copyright (C) 2018 drHatson
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
 //
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // iso14443-4 mifare commands
 //-----------------------------------------------------------------------------
@@ -45,30 +52,39 @@ const char *mfpGetErrorDescription(uint8_t errorCode) {
 }
 
 AccessConditions_t MFAccessConditions[] = {
-    {0x00, "read AB; write AB; increment AB; decrement transfer restore AB"},
-    {0x01, "read AB; decrement transfer restore AB"},
-    {0x02, "read AB"},
-    {0x03, "read B; write B"},
-    {0x04, "read AB; writeB"},
-    {0x05, "read B"},
-    {0x06, "read AB; write B; increment B; decrement transfer restore AB"},
-    {0x07, "none"}
+    {0x00, "read AB; write AB; increment AB; decrement transfer restore AB", "transport config"},
+    {0x01, "read AB; decrement transfer restore AB", "value block"},
+    {0x02, "read AB", "read/write block"},
+    {0x03, "read B; write B", "read/write block"},
+    {0x04, "read AB; write B", "read/write block"},
+    {0x05, "read B", "read/write block"},
+    {0x06, "read AB; write B; increment B; decrement transfer restore AB", "value block"},
+    {0x07, "none", "read/write block"}
 };
 
 AccessConditions_t MFAccessConditionsTrailer[] = {
-    {0x00, "read A by A; read ACCESS by A; read B by A; write B by A"},
-    {0x01, "write A by A; read ACCESS by A write ACCESS by A; read B by A; write B by A"},
-    {0x02, "read ACCESS by A; read B by A"},
-    {0x03, "write A by B; read ACCESS by AB; write ACCESS by B; write B by B"},
-    {0x04, "write A by B; read ACCESS by AB; write B by B"},
-    {0x05, "read ACCESS by AB; write ACCESS by B"},
-    {0x06, "read ACCESS by AB"},
-    {0x07, "read ACCESS by AB"}
+    {0x00, "read A by A; read ACCESS by A; read/write B by A", ""},
+    {0x01, "write A by A; read/write ACCESS by A; read/write B by A", ""},
+    {0x02, "read ACCESS by A; read B by A", ""},
+    {0x03, "write A by B; read ACCESS by AB; write ACCESS by B; write B by B", ""},
+    {0x04, "write A by B; read ACCESS by AB; write B by B", ""},
+    {0x05, "read ACCESS by AB; write ACCESS by B", ""},
+    {0x06, "read ACCESS by AB", ""},
+    {0x07, "read ACCESS by AB", ""}
 };
 
-const char *mfGetAccessConditionsDesc(uint8_t blockn, uint8_t *data) {
-    static char StaticNone[] = "none";
+bool mfValidateAccessConditions(const uint8_t *data) {
+    uint8_t ndata1 = (data[0]) & 0x0f;
+    uint8_t ndata2 = (data[0] >> 4) & 0x0f;
+    uint8_t ndata3 = (data[1]) & 0x0f;
+    uint8_t data1  = (data[1] >> 4) & 0x0f;
+    uint8_t data2  = (data[2]) & 0x0f;
+    uint8_t data3  = (data[2] >> 4) & 0x0f;
 
+    return ((ndata1 == (data1 ^ 0xF)) && (ndata2 == (data2 ^ 0xF)) && (ndata3 == (data3 ^ 0xF)));
+}
+
+const char *mfGetAccessConditionsDesc(uint8_t blockn, const uint8_t *data) {
     uint8_t data1 = ((data[1] >> 4) & 0x0f) >> blockn;
     uint8_t data2 = ((data[2]) & 0x0f) >> blockn;
     uint8_t data3 = ((data[2] >> 4) & 0x0f) >> blockn;
@@ -87,6 +103,7 @@ const char *mfGetAccessConditionsDesc(uint8_t blockn, uint8_t *data) {
             }
     };
 
+    static char StaticNone[] = "none";
     return StaticNone;
 }
 /*
