@@ -1,9 +1,17 @@
 //-----------------------------------------------------------------------------
-// Copyright (C) 2009 Michael Gernoth <michael at gernoth.net>
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
 //
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // GUI (QT)
 //-----------------------------------------------------------------------------
@@ -249,7 +257,7 @@ ProxGuiQT::~ProxGuiQT(void) {
 // Event override functions
 // -------------------------------------------------
 PictureWidget::PictureWidget() {
-    // Set the initail postion and size from settings
+    // Set the initial position and size from settings
 //    if (g_session.preferences_loaded)
 //        setGeometry(g_session.pw.x, g_session.pw.y, g_session.pw.w, g_session.pw.h);
 //    else
@@ -268,7 +276,7 @@ void PictureWidget::closeEvent(QCloseEvent *event) {
 // -------------------------------------------------
 
 SliderWidget::SliderWidget() {
-    // Set the initail postion and size from settings
+    // Set the initial position and size from settings
     if (g_session.preferences_loaded)
         setGeometry(g_session.overlay.x, g_session.overlay.y, g_session.overlay.w, g_session.overlay.h);
     else
@@ -330,7 +338,7 @@ void ProxWidget::vchange_dthr_down(int v) {
 
 ProxWidget::ProxWidget(QWidget *parent, ProxGuiQT *master) : QWidget(parent) {
     this->master = master;
-    // Set the initail postion and size from settings
+    // Set the initial position and size from settings
     if (g_session.preferences_loaded)
         setGeometry(g_session.plot.x, g_session.plot.y, g_session.plot.w, g_session.plot.h);
     else
@@ -379,7 +387,7 @@ ProxWidget::ProxWidget(QWidget *parent, ProxGuiQT *master) : QWidget(parent) {
         controlWidget->resize(size().width(), 200);
     }
 
-    // Olverlays / slider window title
+    // Overlays / slider window title
     QString ct = QString("[*]Slider [ %1 ]").arg(g_conn.serial_port_name);
     controlWidget->setWindowTitle(ct);
 
@@ -1005,8 +1013,9 @@ void Plot::keyPressEvent(QKeyEvent *event) {
             }
             break;
 
-        case Qt::Key_H:
-            g_printAndLog = PRINTANDLOG_PRINT;
+        case Qt::Key_H: {
+            uint8_t old_printAndLog = g_printAndLog;
+            g_printAndLog &= PRINTANDLOG_PRINT;
             PrintAndLogEx(NORMAL, "\n\n" _CYAN_("PLOT window keystrokes and mouse events"));
             PrintAndLogEx(NORMAL, "\n" _GREEN_("Move:"));
             PrintAndLogEx(NORMAL, "    %-*s%s", 25 + 9 + 9, _RED_("Home") "/" _RED_("End"), "Move to the start/end of the graph");
@@ -1031,9 +1040,9 @@ void Plot::keyPressEvent(QKeyEvent *event) {
             PrintAndLogEx(NORMAL, "    %-*s%s", 25 + 9, _YELLOW_("Right mouse click"), "Set purple cursor");
             PrintAndLogEx(NORMAL, "    %-*s%s", 25 + 9, _RED_("h"), "Show this help");
             PrintAndLogEx(NORMAL, "    %-*s%s", 25 + 9, _RED_("q"), "Close plot window");
-            g_printAndLog = PRINTANDLOG_PRINT | PRINTANDLOG_LOG;
+            g_printAndLog = old_printAndLog;
             break;
-
+        }
         case Qt::Key_L:
             g_GridLocked = !g_GridLocked;
             if (g_GridLocked)
