@@ -1,10 +1,17 @@
 //-----------------------------------------------------------------------------
-// Copyright (C) 2009 Michael Gernoth <michael at gernoth.net>
-// Copyright (C) 2010 iZsh <izsh at fail0verflow.com>
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
 //
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // Main binary
 //-----------------------------------------------------------------------------
@@ -18,6 +25,7 @@
 #ifdef HAVE_READLINE
 #include <readline/readline.h>
 #include <readline/history.h>
+#include "rl_vocabulory.h"
 #include <signal.h>
 #endif
 #include <ctype.h>
@@ -37,8 +45,8 @@
 
 #ifndef LIBPM3
 #define BANNERMSG1 ""
-#define BANNERMSG2 "   [ :snowflake: Iceman :snowflake: ]"
-#define BANNERMSG3 "Release v4.14434 - crimson"
+#define BANNERMSG2 "   [ Iceman :snowflake: ]"
+#define BANNERMSG3 "Release v4.14831 - Frostbit"
 
 typedef enum LogoMode { UTF8, ANSI, ASCII } LogoMode;
 
@@ -92,8 +100,8 @@ static void showBanner_logo(LogoMode mode) {
 }
 
 static void showBanner(void) {
-
-    g_printAndLog = PRINTANDLOG_PRINT;
+    uint8_t old_printAndLog = g_printAndLog;
+    g_printAndLog &= PRINTANDLOG_PRINT;
     PrintAndLogEx(NORMAL, "\n");
 
 #if defined(_WIN32)
@@ -113,7 +121,7 @@ static void showBanner(void) {
 //    PrintAndLogEx(NORMAL, "\nMonero: 43mNJLpgBVaTvyZmX9ajcohpvVkaRy1kbZPm8tqAb7itZgfuYecgkRF36rXrKFUkwEGeZedPsASRxgv4HPBHvJwyJdyvQuP");
     PrintAndLogEx(NORMAL, "");
     fflush(stdout);
-    g_printAndLog = PRINTANDLOG_PRINT | PRINTANDLOG_LOG;
+    g_printAndLog = old_printAndLog;
 }
 #endif //LIBPM3
 
@@ -147,6 +155,7 @@ static void flush_history(void) {
     if (g_session.history_path) {
         write_history(g_session.history_path);
         free(g_session.history_path);
+        g_session.history_path = NULL;
     }
 }
 
@@ -250,13 +259,11 @@ main_loop(char *script_cmds_file, char *script_cmd, bool stayInCommandLoop) {
     bool stdinOnPipe = !isatty(STDIN_FILENO);
     char script_cmd_buf[256] = {0x00};  // iceman, needs lua script the same file_path_buffer as the rest
 
-    if (g_session.pm3_present) {
-        // cache Version information now:
-        if (execCommand || script_cmds_file || stdinOnPipe)
-            pm3_version(false, false);
-        else
-            pm3_version(true, false);
-    }
+    // cache Version information now:
+    if (execCommand || script_cmds_file || stdinOnPipe)
+        pm3_version(false, false);
+    else
+        pm3_version(true, false);
 
     if (script_cmds_file) {
 
@@ -436,8 +443,9 @@ check_script:
             cmd[strlen(cmd) - off] = '\0';
 
             if (cmd[0] != '\0') {
+                uint8_t old_printAndLog = g_printAndLog;
                 if (!printprompt) {
-                    g_printAndLog = PRINTANDLOG_LOG;
+                    g_printAndLog &= PRINTANDLOG_LOG;
                 }
                 char prompt[PROXPROMPT_MAX_SIZE] = {0};
                 prompt_compose(prompt, sizeof(prompt), prompt_ctx, prompt_dev);
@@ -445,7 +453,7 @@ check_script:
                 char prompt_filtered[PROXPROMPT_MAX_SIZE] = {0};
                 memcpy_filter_rlmarkers(prompt_filtered, prompt, sizeof(prompt_filtered));
                 PrintAndLogEx(NORMAL, "%s%s", prompt_filtered, cmd);
-                g_printAndLog = PRINTANDLOG_PRINT | PRINTANDLOG_LOG;
+                g_printAndLog = old_printAndLog;
 
 #ifdef HAVE_READLINE
                 // add to history if not from a script
@@ -598,7 +606,11 @@ static void set_my_user_directory(void) {
 static void show_help(bool showFullHelp, char *exec_name) {
 
     PrintAndLogEx(NORMAL, "\nsyntax: %s [-h|-t|-m|--fulltext]", exec_name);
+#ifdef HAVE_PYTHON
+    PrintAndLogEx(NORMAL, "        %s [[-p] <port>] [-b] [-w] [-f] [-c <command>]|[-l <lua_script_file>]|[-y <python_script_file>]|[-s <cmd_script_file>] [-i] [-d <0|1|2>]", exec_name);
+#else // HAVE_PYTHON
     PrintAndLogEx(NORMAL, "        %s [[-p] <port>] [-b] [-w] [-f] [-c <command>]|[-l <lua_script_file>]|[-s <cmd_script_file>] [-i] [-d <0|1|2>]", exec_name);
+#endif // HAVE_PYTHON
     PrintAndLogEx(NORMAL, "        %s [-p] <port> --flash [--unlock-bootloader] [--image <imagefile>]+ [-w] [-f] [-d <0|1|2>]", exec_name);
 
     if (showFullHelp) {
@@ -616,7 +628,11 @@ static void show_help(bool showFullHelp, char *exec_name) {
         PrintAndLogEx(NORMAL, "      -m/--markdown                       dump all interactive command list at once in markdown syntax");
         PrintAndLogEx(NORMAL, "      -b/--baud                           serial port speed (only needed for physical UART, not for USB-CDC or BT)");
         PrintAndLogEx(NORMAL, "      -c/--command <command>              execute one Proxmark3 command (or several separated by ';').");
-        PrintAndLogEx(NORMAL, "      -l/--lua <lua script file>          execute lua script.");
+        PrintAndLogEx(NORMAL, "      -l/--lua <lua_script_file>          execute Lua script.");
+#ifdef HAVE_PYTHON
+        // Technically, --lua and --py are identical and interexchangeable
+        PrintAndLogEx(NORMAL, "      -y/--py <python_script_file>        execute Python script.");
+#endif // HAVE_PYTHON
         PrintAndLogEx(NORMAL, "      -s/--script-file <cmd_script_file>  script file with one Proxmark3 command per line");
         PrintAndLogEx(NORMAL, "      -i/--interactive                    enter interactive mode after executing the script or the command");
         PrintAndLogEx(NORMAL, "      --incognito                         do not use history, prefs file nor log files");
@@ -627,12 +643,12 @@ static void show_help(bool showFullHelp, char *exec_name) {
         PrintAndLogEx(NORMAL, "\nExamples:");
         PrintAndLogEx(NORMAL, "\n  to run Proxmark3 client:\n");
         PrintAndLogEx(NORMAL, "      %s "SERIAL_PORT_EXAMPLE_H"                       -- runs the pm3 client", exec_name);
-        PrintAndLogEx(NORMAL, "      %s "SERIAL_PORT_EXAMPLE_H" -f                    -- flush output everytime", exec_name);
+        PrintAndLogEx(NORMAL, "      %s "SERIAL_PORT_EXAMPLE_H" -f                    -- flush output every time", exec_name);
         PrintAndLogEx(NORMAL, "      %s "SERIAL_PORT_EXAMPLE_H" -w                    -- wait for serial port", exec_name);
         PrintAndLogEx(NORMAL, "      %s                                    -- runs the pm3 client in OFFLINE mode", exec_name);
         PrintAndLogEx(NORMAL, "\n  to execute different commands from terminal:\n");
         PrintAndLogEx(NORMAL, "      %s "SERIAL_PORT_EXAMPLE_H" -c \"hf mf chk --1k\"   -- execute cmd and quit client", exec_name);
-        PrintAndLogEx(NORMAL, "      %s "SERIAL_PORT_EXAMPLE_H" -l hf_read            -- execute lua script `hf_read` and quit client", exec_name);
+        PrintAndLogEx(NORMAL, "      %s "SERIAL_PORT_EXAMPLE_H" -l hf_read            -- execute Lua script `hf_read` and quit client", exec_name);
         PrintAndLogEx(NORMAL, "      %s "SERIAL_PORT_EXAMPLE_H" -s mycmds.txt         -- execute each pm3 cmd in file and quit client", exec_name);
         PrintAndLogEx(NORMAL, "\n  to flash fullimage and bootloader:\n");
         PrintAndLogEx(NORMAL, "      %s "SERIAL_PORT_EXAMPLE_H" --flash --unlock-bootloader --image bootrom.elf --image fullimage.elf", exec_name);
@@ -757,7 +773,7 @@ void pm3_init(void) {
 int main(int argc, char *argv[]) {
     pm3_init();
     bool waitCOMPort = false;
-    bool addLuaExec = false;
+    bool addScriptExec = false;
     bool stayInCommandLoop = false;
     char *script_cmds_file = NULL;
     char *script_cmd = NULL;
@@ -768,6 +784,9 @@ int main(int argc, char *argv[]) {
     /* initialize history */
     using_history();
 
+    rl_readline_name = "PM3";
+    rl_attempted_completion_function = rl_command_completion;
+
 #ifdef RL_STATE_READCMD
     rl_extend_line_buffer(1024);
 #endif // RL_STATE_READCMD
@@ -940,10 +959,10 @@ int main(int argc, char *argv[]) {
             continue;
         }
 
-        // execute lua script
+        // execute Lua script
         if (strcmp(argv[i], "-l") == 0 || strcmp(argv[i], "--lua") == 0) {
             if (i + 1 == argc || strlen(argv[i + 1]) == 0) {
-                PrintAndLogEx(ERR, _RED_("ERROR:") " missing lua script specification after -l\n");
+                PrintAndLogEx(ERR, _RED_("ERROR:") " missing Lua script specification after --lua\n");
                 show_help(false, exec_name);
                 return 1;
             }
@@ -951,10 +970,25 @@ int main(int argc, char *argv[]) {
             if (script_cmd == NULL || strlen(script_cmd) == 0) {
                 return 1;
             }
-            addLuaExec = true;
+            addScriptExec = true;
             continue;
         }
-
+#ifdef HAVE_PYTHON
+        // execute Python script
+        if (strcmp(argv[i], "-y") == 0 || strcmp(argv[i], "--py") == 0) {
+            if (i + 1 == argc || strlen(argv[i + 1]) == 0) {
+                PrintAndLogEx(ERR, _RED_("ERROR:") " missing Python script specification after --py\n");
+                show_help(false, exec_name);
+                return 1;
+            }
+            script_cmd = argv[++i];
+            if (script_cmd == NULL || strlen(script_cmd) == 0) {
+                return 1;
+            }
+            addScriptExec = true;
+            continue;
+        }
+#endif // HAVE_PYTHON
         // go to interactive instead of quitting after a script/command
         if (strcmp(argv[i], "-i") == 0 || strcmp(argv[i], "--interactive") == 0) {
             stayInCommandLoop = true;
@@ -1033,7 +1067,7 @@ int main(int argc, char *argv[]) {
             PrintAndLogEx(ERR, _RED_("ERROR:") " execute command: " _YELLOW_("command not found") ".\n");
             return 2;
         } else {
-            if (addLuaExec) {
+            if (addScriptExec) {
                 // add "script run " to command
                 int len = strlen(script_cmd) + 11 + 1;
                 char *ctmp = (char *) calloc(len, sizeof(uint8_t));
