@@ -1,10 +1,17 @@
 //-----------------------------------------------------------------------------
-// Copyright (C) 2013 m h swende <martin at swende.se>
-// Modified 2015,2016, iceman
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
 //
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // Some lua scripting glue to proxmark core.
 //-----------------------------------------------------------------------------
@@ -683,13 +690,29 @@ static int l_aes128encrypt_ecb(lua_State *L) {
 
 static int l_crc8legic(lua_State *L) {
     size_t size;
-    const char *p_str = luaL_checklstring(L, 1, &size);
-
-    uint16_t retval = CRC8Legic((uint8_t *) p_str, size);
+    const char *p_hexstr = luaL_checklstring(L, 1, &size);
+    uint16_t retval = CRC8Legic((uint8_t *)p_hexstr, size);
     lua_pushunsigned(L, retval);
     return 1;
 }
 
+static int l_crc16legic(lua_State *L) {
+    size_t hexsize, uidsize;
+
+    // data as hex string
+    const char *p_hexstr = luaL_checklstring(L, 1, &hexsize);
+
+    // calc uid crc based on uid hex
+    const char *p_uid = luaL_checklstring(L, 2, &uidsize);
+    uint16_t uidcrc = CRC8Legic((uint8_t *)p_uid, uidsize);
+
+    init_table(CRC_LEGIC_16);
+    uint16_t retval = crc16_legic((uint8_t *)p_hexstr, hexsize, uidcrc);
+    lua_pushunsigned(L, retval);
+    return 1;
+}
+
+
 static int l_crc16(lua_State *L) {
     size_t size;
     const char *p_str = luaL_checklstring(L, 1, &size);
@@ -1359,6 +1382,7 @@ int set_pm3_libraries(lua_State *L) {
         {"aes128_encrypt",              l_aes128encrypt_cbc},
         {"aes128_encrypt_ecb",          l_aes128encrypt_ecb},
         {"crc8legic",                   l_crc8legic},
+        {"crc16legic",                  l_crc16legic},
         {"crc16",                       l_crc16},
         {"crc64",                       l_crc64},
         {"crc64_ecma182",               l_crc64_ecma182},
