@@ -1,9 +1,17 @@
 //-----------------------------------------------------------------------------
-// Copyright (C) 2010 iZsh <izsh at fail0verflow.com>
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
 //
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // utilities
 //-----------------------------------------------------------------------------
@@ -447,7 +455,7 @@ int hex_to_bytes(const char *hexValue, uint8_t *bytesValue, size_t maxBytesValue
         }
 
         if (maxBytesValueLen && bytesValueLen >= maxBytesValueLen) {
-            // if we dont have space in buffer and have symbols to translate
+            // if we don't have space in buffer and have symbols to translate
             return -2;
         }
 
@@ -718,7 +726,7 @@ int param_gethex_to_eol(const char *line, int paramnum, uint8_t *data, int maxda
         }
 
         if (*datalen >= maxdatalen) {
-            // if we dont have space in buffer and have symbols to translate
+            // if we don't have space in buffer and have symbols to translate
             return 2;
         }
 
@@ -763,7 +771,7 @@ int param_getbin_to_eol(const char *line, int paramnum, uint8_t *data, int maxda
         }
 
         if (*datalen >= maxdatalen) {
-            // if we dont have space in buffer and have symbols to translate
+            // if we don't have space in buffer and have symbols to translate
             return 2;
         }
 
@@ -843,7 +851,7 @@ int hextobinstring(char *target, char *source) {
 
 // convert binary array of 0x00/0x01 values to hex
 // return number of bits converted
-int binarraytohex(char *target, const size_t targetlen, char *source, size_t srclen) {
+int binarraytohex(char *target, const size_t targetlen, const char *source, size_t srclen) {
     uint8_t i = 0, x = 0;
     uint32_t t = 0; // written target chars
     uint32_t r = 0; // consumed bits
@@ -914,7 +922,7 @@ int binstring2binarray(uint8_t *target, char *source, int length) {
 }
 
 // return parity bit required to match type
-uint8_t GetParity(uint8_t *bits, uint8_t type, int length) {
+uint8_t GetParity(const uint8_t *bits, uint8_t type, int length) {
     int x;
     for (x = 0 ; length > 0 ; --length)
         x += bits[length - 1];
@@ -939,7 +947,7 @@ void wiegand_add_parity_swapped(uint8_t *target, uint8_t *source, uint8_t length
 }
 
 // Pack a bitarray into a uint32_t.
-uint32_t PackBits(uint8_t start, uint8_t len, uint8_t *bits) {
+uint32_t PackBits(uint8_t start, uint8_t len, const uint8_t *bits) {
 
     if (len > 32) return 0;
 
@@ -1082,7 +1090,7 @@ int binstring_to_u96(uint32_t *hi2, uint32_t *hi, uint32_t *lo, const char *str)
  *
  * Returns the number of bits entered.
  */
-int binarray_to_u96(uint32_t *hi2, uint32_t *hi, uint32_t *lo, uint8_t *arr, int arrlen) {
+int binarray_to_u96(uint32_t *hi2, uint32_t *hi, uint32_t *lo, const uint8_t *arr, int arrlen) {
     int i = 0;
     for (; i < arrlen; i++) {
         uint8_t n = arr[i];
