@@ -1,9 +1,17 @@
 //-----------------------------------------------------------------------------
-// Jonathan Westhues, Aug 2005
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
 //
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // Utility functions used in many places, not specific to any piece of code.
 //-----------------------------------------------------------------------------
@@ -53,12 +61,12 @@ void num_to_bytes(uint64_t n, size_t len, uint8_t *dest);
 uint64_t bytes_to_num(uint8_t *src, size_t len);
 
 // LE and BE to/from memory
-uint16_t MemLeToUint2byte(uint8_t *data);
-uint32_t MemLeToUint3byte(uint8_t *data);
-uint32_t MemLeToUint4byte(uint8_t *data);
-uint16_t MemBeToUint2byte(uint8_t *data);
-uint32_t MemBeToUint3byte(uint8_t *data);
-uint32_t MemBeToUint4byte(uint8_t *data);
+uint16_t MemLeToUint2byte(const uint8_t *data);
+uint32_t MemLeToUint3byte(const uint8_t *data);
+uint32_t MemLeToUint4byte(const uint8_t *data);
+uint16_t MemBeToUint2byte(const uint8_t *data);
+uint32_t MemBeToUint3byte(const uint8_t *data);
+uint32_t MemBeToUint4byte(const uint8_t *data);
 void Uint2byteToMemLe(uint8_t *data, uint16_t value);
 void Uint3byteToMemLe(uint8_t *data, uint32_t value);
 void Uint4byteToMemLe(uint8_t *data, uint32_t value);
@@ -69,10 +77,12 @@ void Uint4byteToMemBe(uint8_t *data, uint32_t value);
 // rotate left byte array
 void rol(uint8_t *data, const size_t len);
 void lsl(uint8_t *data, size_t len);
-uint32_t le24toh(uint8_t data[3]);
+uint32_t le24toh(const uint8_t data[3]);
 void htole24(uint32_t val, uint8_t data[3]);
 
 // rol on a u32
 uint32_t rotl(uint32_t a, uint8_t n);
 uint32_t rotr(uint32_t a, uint8_t n);
+
+uint16_t get_sw(const uint8_t *d, uint8_t n);
 #endif
