@@ -18,7 +18,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Modifed Iceman, 2020
+ * Modified Iceman, 2020
  */
 
 #include <stdio.h>
@@ -192,7 +192,7 @@ static inline uint8_t bit_rotate_r(uint8_t a, uint8_t n_bits) {
 #define BIT_ROR(a)       (((a) >> 1) | (((a) & 1) << 4))
 
 
-static uint8_t lookup_left_substraction[0x400];
+static uint8_t lookup_left_subtraction[0x400];
 static uint8_t lookup_right_subtraction[0x400];
 static lookup_entry lookup_left[0x100000];
 static lookup_entry lookup_right[0x8000];
@@ -232,17 +232,17 @@ static inline void init_lookup_right() {
     }
 }
 
-static void init_lookup_left_substraction() {
+static void init_lookup_left_subtraction() {
     for (int index = 0; index < 0x400 ; index++) {
         uint8_t b3 = (index >> 5 & 0x1f);
         uint8_t bx = (index & 0x1f);
 
-        //lookup_left_substraction[index] = bit_rotate_r(mod((bx+0x1f)-b3,0x1f),5);
-        lookup_left_substraction[index] = BIT_ROR(mod((bx + 0x1F) - b3, 0x1F));
+        //lookup_left_subtraction[index] = bit_rotate_r(mod((bx+0x1f)-b3,0x1f),5);
+        lookup_left_subtraction[index] = BIT_ROR(mod((bx + 0x1F) - b3, 0x1F));
     }
 }
 
-static void init_lookup_right_substraction() {
+static void init_lookup_right_subtraction() {
     for (int index = 0; index < 0x400 ; index++) {
         int b16 = (index >> 5);
         uint8_t bx = (index & 0x1f);
@@ -271,7 +271,7 @@ static inline void previous_left(uint8_t in, vector<cs_t> *candidate_states) {
                 state->l ^= (((uint64_t)in & 0x1f) << 20);
             }
         } else {
-            uint8_t b6 = lookup_left_substraction[b3 | bx];
+            uint8_t b6 = lookup_left_subtraction[b3 | bx];
             state->l = (state->l & 0x7ffffffe0ull) | b6;
             state->l ^= (((uint64_t)in & 0x1f) << 20);
 
@@ -470,7 +470,7 @@ static uint32_t ice_sm_right(const uint8_t *ks, uint8_t *mask, vector<uint64_t>
         pcrstates->push_back(it->second);
     }
 
-    // Reverse the vector order (so the higest bin comes first)
+    // Reverse the vector order (so the highest bin comes first)
     reverse(pcrstates->begin(), pcrstates->end());
 
     return g_topbits;
@@ -481,7 +481,7 @@ static void ice_sm_left_thread(
     uint8_t skips,
     const uint8_t *ks,
     map<uint64_t, cs_t> *bincstates,
-    uint8_t *mask
+    const uint8_t *mask
 ) {
 
     size_t pos, bits;
@@ -583,7 +583,7 @@ static void ice_sm_left(const uint8_t *ks, uint8_t *mask, vector<cs_t> *pcstates
     for (it = bincstates.begin(); it != bincstates.end(); ++it) {
         pcstates->push_back(it->second);
     }
-    // Reverse the vector order (so the higest bin comes first)
+    // Reverse the vector order (so the highest bin comes first)
     reverse(pcstates->begin(), pcstates->end());
 }
 
@@ -649,7 +649,7 @@ static inline uint32_t sm_right(const uint8_t *ks, uint8_t *mask, vector<uint64_
         pcrstates->push_back(it->second);
     }
 
-    // Reverse the vector order (so the higest bin comes first)
+    // Reverse the vector order (so the highest bin comes first)
     reverse(pcrstates->begin(), pcrstates->end());
 
     return topbits;
@@ -741,7 +741,7 @@ static inline void search_gc_candidates_right(const uint64_t rstate_before_gc, c
     }
 }
 
-static inline void sm_left(const uint8_t *ks, uint8_t *mask, vector<cs_t> *pcstates) {
+static inline void sm_left(const uint8_t *ks, const uint8_t *mask, vector<cs_t> *pcstates) {
     map<uint64_t, cs_t> bincstates;
     map<uint64_t, cs_t>::iterator it;
     uint64_t counter, lstate;
@@ -825,7 +825,7 @@ static inline void sm_left(const uint8_t *ks, uint8_t *mask, vector<cs_t> *pcsta
     for (it = bincstates.begin(); it != bincstates.end(); ++it) {
         pcstates->push_back(it->second);
     }
-    // Reverse the vector order (so the higest bin comes first)
+    // Reverse the vector order (so the highest bin comes first)
     reverse(pcstates->begin(), pcstates->end());
 }
 
@@ -991,8 +991,8 @@ int main(int argc, const char *argv[]) {
 
     uint64_t nCi;   // Card random
     uint64_t nQ;    // Reader random
-    uint64_t nCh;   // Reader challange
-    uint64_t nCi_1; // Card anwser
+    uint64_t nCh;   // Reader challenge
+    uint64_t nCi_1; // Card answer
 
     if ((argc != 2) && (argc != 5)) {
         printf("SecureMemory recovery - (c) Radboud University Nijmegen\n\n");
@@ -1050,8 +1050,8 @@ int main(int argc, const char *argv[]) {
 
     std::thread foo_left(init_lookup_left);
     std::thread foo_right(init_lookup_right);
-    std::thread foo_leftsub(init_lookup_left_substraction);
-    std::thread foo_rightsub(init_lookup_right_substraction);
+    std::thread foo_leftsub(init_lookup_left_subtraction);
+    std::thread foo_rightsub(init_lookup_right_subtraction);
 
     foo_left.join();
     foo_right.join();
